{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# L-BFGS vs GD\n",
    "\n",
    "Curiously, the original L-BFGS convergence proof essentially reduces the L-BFGS iteration to GD. This establishes L-BFGS converges globally for sufficiently regular functions and also that it has local linear convergence, just like GD, for smooth and strongly convex functions.\n",
    "\n",
    "But if you look carefully at the proof, the construction is very strange: the more memory L-BFGS uses the less it looks like GD, the worse the smoothness constants are for the actual local rate of convergence. I go to into more detail on this in my [SO question](https://scicomp.stackexchange.com/questions/36166/when-does-l-bfgs-outperform-gd) on the topic, but I was curious about some empirical assessments of how these compare.\n",
    "\n",
    "I found a [study](http://math.furman.edu/~mwoodard/fuejum/content/2007/paper2_2007.pdf) which confirms high-level intuition: L-BFGS interpolates between CG and BFGS as you increase memory. This relationship is true in a limiting sense: when $L=0$ L-BFGS is equal to a flavor of CG (with exact line search) and when $L=\\infty$ it's BFGS. BFGS, in turn, iteratively constructs approximations $B_k$ to the Hessian which eventually satisfy a directional inequality $\\|(B_k-\\nabla_k^2)\\mathbf{p}_k\\|=o(\\|\\mathbf{p}_k\\|)$ where $\\mathbf{p}_k=-B_k^{-1}\\nabla_k$ is the descent direction, which it turns out is enough to be \"close enough\" to Newton that you can achieve superlinear convergence rates.\n",
    "\n",
    "So, to what extent does agreement between $\\mathbf{p}_k,\\nabla_k$ (measured as $\\cos^2 \\theta_k$, the square of the cosine of the angle between the two) explain fast L-BFGS convergence? How about the magnitude of the Hessian-approximate-BFGS-Hessian agreement along the descent direction $\\|(B_k-\\nabla_k^2)\\mathbf{p}_k\\|$? What about the secant equation difference?\n",
    "\n",
    "One interesting hypothesis is that the low-rank view L-BFGS has into the Hessian means that it can't approximate the Hessian well if its eigenvalues are spread far apart (since you need to \"spend\" rank to explore parts of the eigenspace).\n",
    "\n",
    "Let's take some simple overdetermined least squares systems with varying eigenspectra and see how all the metrics above respond."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "from numpy_ringbuffer import RingBuffer\n",
    "import numpy as np\n",
    "from scipy.stats import special_ortho_group\n",
    "from scipy import linalg as sla\n",
    "%matplotlib inline\n",
    "from matplotlib import pyplot as plt\n",
    "from scipy.optimize import line_search\n",
    "\n",
    "class LBFGS:\n",
    "    def __init__(self, m, d, x0, g0):\n",
    "        self.s = RingBuffer(capacity=m, dtype=(float, d))\n",
    "        self.y = RingBuffer(capacity=m, dtype=(float, d))\n",
    "        self.x = x0.copy()\n",
    "        self.g = g0.copy()\n",
    "    \n",
    "    def mvm(self, q):\n",
    "        q = q.copy()\n",
    "        m = len(self.s)\n",
    "        alphas = np.zeros(m, dtype=float)\n",
    "        for i, (s, y) in enumerate(zip(reversed(self.s), reversed(self.y))):\n",
    "            inv_rho = s.dot(y)\n",
    "            alphas[m - i - 1] = s.dot(q) / inv_rho\n",
    "            q -= alphas[m - i - 1] * y\n",
    "        if m > 0:\n",
    "            s = next(reversed(self.s))\n",
    "            y = next(reversed(self.y))\n",
    "            gamma = s.dot(y) / y.dot(y)\n",
    "        else:\n",
    "            gamma = 1\n",
    "        z = gamma * q\n",
    "        for (alpha, s, y) in zip(alphas, self.s, self.y):\n",
    "            inv_rho = s.dot(y)\n",
    "            beta = y.dot(z) / inv_rho\n",
    "            z += s * (alpha - beta)\n",
    "        return -z\n",
    "    \n",
    "    # mvm(self, self.g) gives current lbfgs direction\n",
    "    # - H g\n",
    "    \n",
    "    def update(self, x, g):\n",
    "        s = x - self.x\n",
    "        y = g - self.g\n",
    "        if self.s.is_full:\n",
    "            assert self.y.is_full\n",
    "            self.s.popleft()\n",
    "            self.y.popleft()\n",
    "        self.s.append(s)\n",
    "        self.y.append(y)\n",
    "        self.x = x.copy()\n",
    "        self.g = g.copy()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "from scipy.optimize.linesearch import line_search_armijo\n",
    "\n",
    "def haar(n, d, rng=np.random):\n",
    "    # https://nhigham.com/2020/04/22/what-is-a-random-orthogonal-matrix/\n",
    "    assert n >= d\n",
    "    z = rng.normal(size=(n, d))\n",
    "    if n > d:\n",
    "        q, r = sla.qr(z, mode='economic')\n",
    "    else:\n",
    "        q, r = sla.qr(z, mode='full')\n",
    "    assert q.shape[1] == d, (q.shape[1], d)\n",
    "    return q\n",
    "\n",
    "np.random.seed(1234)\n",
    "d = 100\n",
    "n = 1000\n",
    "vt = haar(d, d)\n",
    "u = haar(n, d)\n",
    "\n",
    "# bottom singular value we'll keep at 1\n",
    "# so top determines the condition number\n",
    "# for a vector s of singular values\n",
    "# A = u diag(s) vt\n",
    "# objective = 1/2 ||Ax - 1||_2^2\n",
    "\n",
    "x0 = np.zeros(d)\n",
    "b = np.ones(n)\n",
    "\n",
    "def xopt(A):\n",
    "    u, s, vt = A\n",
    "    return vt.T.dot(u.T.dot(b) / s)\n",
    "\n",
    "def objective(A, x):\n",
    "    u, s, vt = A\n",
    "    vtx = vt.dot(x)\n",
    "    Ax = u.dot(s * vtx)\n",
    "    diff = Ax - b\n",
    "    f = diff.dot(diff) / 2\n",
    "    g = vt.T.dot(s * (s * vtx - u.T.dot(b)))\n",
    "    return f, g\n",
    "\n",
    "def hessian_mvm(A, q):\n",
    "    u, s, vt = A\n",
    "    return vt.T.dot(s * (s * vt.dot(q)))\n",
    "\n",
    "def gd(A, max_iter=1000, tol=1e-11, c1=0.2, c2=0.8, armijo=False):\n",
    "    x = x0.copy()\n",
    "    xsol = xopt(A)\n",
    "    fsol = objective(A, xsol)[0]\n",
    "    gaps = []\n",
    "    for _ in range(max_iter):\n",
    "        f, g = objective(A, x)\n",
    "        gaps.append(abs(f - fsol))\n",
    "        if gaps[-1] < tol:\n",
    "            break\n",
    "        if armijo:\n",
    "            alpha, *_ = line_search_armijo(\n",
    "                lambda x: objective(A, x)[0],\n",
    "                x, -g, g, f)\n",
    "        else:\n",
    "            alpha = line_search(\n",
    "                lambda x: objective(A, x)[0],\n",
    "                lambda x: objective(A, x)[1],\n",
    "                x, -g, maxiter=1000,\n",
    "                c1=c1, c2=c2)\n",
    "            if alpha[0] is None:\n",
    "                raise RuntimeError((alpha, g, x))\n",
    "            alpha = alpha[0]\n",
    "        x -= alpha * g\n",
    "    return gaps\n",
    "\n",
    "def lbfgs(A, m, max_iter=1000, tol=1e-11, extras=False, c1=0.2, c2=0.8, armijo=False):\n",
    "    x = x0.copy()\n",
    "    xsol = xopt(A)\n",
    "    fsol = objective(A, xsol)[0]\n",
    "    gaps = []\n",
    "    if extras:\n",
    "        newton = []\n",
    "        cosine = []\n",
    "    \n",
    "    f, g = objective(A, x)\n",
    "    opt = LBFGS(m, d, x, g)\n",
    "\n",
    "    for i in range(max_iter):\n",
    "        gaps.append(abs(f - fsol))\n",
    "        p = opt.mvm(opt.g)\n",
    "        \n",
    "        if extras:\n",
    "            newton.append(np.linalg.norm(\n",
    "                hessian_mvm(A, p) - opt.mvm(p)\n",
    "            ) / np.linalg.norm(p))\n",
    "            cosine.append(1 - p.dot(-g) / np.linalg.norm(p) / np.linalg.norm(g))\n",
    "        if gaps[-1] < tol:\n",
    "            break \n",
    "        if armijo:\n",
    "            alpha, *_ = line_search_armijo(\n",
    "                lambda x: objective(A, x)[0],\n",
    "                x, p, opt.g, f)\n",
    "        else:\n",
    "            alpha = line_search(\n",
    "                lambda x: objective(A, x)[0],\n",
    "                lambda x: objective(A, x)[1],\n",
    "                x, p, maxiter=1000,\n",
    "                c1=c1, c2=c2)\n",
    "            if alpha[0] is None:\n",
    "                raise RuntimeError(alpha)\n",
    "            alpha = alpha[0]\n",
    "        x += alpha * p\n",
    "        f, g = objective(A, x)\n",
    "        opt.update(x, g)\n",
    "    if extras:\n",
    "        return gaps, newton, cosine\n",
    "    return gaps"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAj8AAAEWCAYAAACJ5/ZUAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nU6dY8mOMMcaYOuX/AUXRg7CBJ5QEAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<Figure size 432x288 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "for kappa, ls in [(10, '-'), (50, '--')]:\n",
    "    s = np.linspace(1, kappa, d)\n",
    "    A = (u, s, vt)\n",
    "    gds = gd(A)\n",
    "    memory = 10\n",
    "    lbs = lbfgs(A, memory)\n",
    "    matrix_name = 'linspace eigenvals'\n",
    "    plt.semilogy(gds, c='b', label=r'GD ($\\kappa = {kappa}$)'.format(kappa=kappa), ls=ls)\n",
    "    plt.semilogy(lbs, c='r', ls=ls,\n",
    "                 label=r'L-BFGS ($m = {memory}, \\kappa = {kappa}$)'.format(\n",
    "                     kappa=kappa, memory=memory))\n",
    "plt.legend(bbox_to_anchor=(1.05, 0.5), loc='center left')\n",
    "plt.xlabel('iterations')\n",
    "plt.ylabel('function optimality gap')\n",
    "plt.title(matrix_name)\n",
    "plt.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "OK, so pretty interestingly, L-BFGS is still fundamentally linear in terms of its convergence rate (which translates to $\\log \\epsilon^{-1}$ speed for quadratic problems like ours). But clearly it gets better bang for its buck in the rate itself. And this is obviously important---even though the $\\kappa = 50$ GD is still \"exponentially fast\", it's clear that the small slope means it'll still take a practically long time to converge. We know from [explicit analysis](https://calculus.subwiki.org/wiki/Gradient_descent_with_exact_line_search_for_a_quadratic_function_of_multiple_variables) that the GD linear rate will be something like $((\\kappa - 1)/\\kappa)^2$. If you squint really hard, that's basically $((1-\\kappa^{-1})^\\kappa)^{2/\\kappa}\\approx e^{-2/\\kappa}$ for large $\\kappa$, which is why our \"exponential rates\" look not-so-exponential, especially for $\\kappa$ near the number of iterations (because then the suboptimality gap looks like $r^{T/\\kappa}$ for $T$ iterations and $r=e^{-2}$).\n",
    "\n",
    "It's interesting to compare how sensitive L-BFGS and GD are to the condition number increase. Yes, we're fixing the eigenvalue pattern to be a linear spread, but let's save inspecting that to the end.\n",
    "\n",
    "The linear rate is effectively the slope that the log plot has at the end. While we're at it, what's the effect of more memory?"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAhEAAAEWCAYAAADYc8U3AAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nViA6idA0TdM0rUD+H6JtF8PlM8m6AAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<Figure size 432x288 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "for memory, ls in [(10, '-'), (25, '--'), (50, ':')]:\n",
    "    for kappa, color in [(10, 'r'), (25, 'b'), (50, 'g')]:\n",
    "        s = np.linspace(1, kappa, d)\n",
    "        A = (u, s, vt)\n",
    "        lbs = lbfgs(A, memory)\n",
    "        plt.semilogy(lbs, c=color, ls=ls,\n",
    "                     label=r'$\\kappa = {kappa}, m = {memory}$'.format(\n",
    "                        memory=memory, kappa=kappa))\n",
    "\n",
    "plt.legend(bbox_to_anchor=(1.05, 0.5), loc='center left')\n",
    "plt.xlabel('iterations')\n",
    "plt.ylabel('function optimality gap')\n",
    "plt.title(matrix_name)\n",
    "plt.show('linspace eigenvals (L-BFGS)')"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Now that's pretty cool, it looks like the limiting behavior is still ultimately linear (as expected, it takes about as many iterations as the memory size for the limiting behavior to \"kick in\"), but as memory increases, the rate gets better. What if we make the eigenvalues clumpy?"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAhAAAAEWCAYAAAA3sa4JAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nStXZ/wMaJCh4+59jFQAAAABJRU5ErkJggg==\n",
      "text/plain": [
       "<Figure size 432x288 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAhEAAAEWCAYAAADYc8U3AAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<Figure size 432x288 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "for memory, ls in [(10, '-'), (25, '--'), (50, ':')]:\n",
    "    for kappa, color in [(10, 'r'), (25, 'b'), (50, 'g')]:\n",
    "        bot, mid, top = d // 3, d // 3, d - 2 * d // 3\n",
    "        s = [1] * bot + [kappa / 2] * mid + [kappa] * top\n",
    "        s = np.array(s)\n",
    "        A = (u, s, vt)\n",
    "        lbs = lbfgs(A, memory)\n",
    "        plt.semilogy(lbs, c=color, ls=ls,\n",
    "                     label=r'$\\kappa = {kappa}, m = {memory}$'.format(\n",
    "                        memory=memory, kappa=kappa))\n",
    "\n",
    "plt.legend(bbox_to_anchor=(1.05, 0.5), loc='center left')\n",
    "plt.xlabel('iterations')\n",
    "plt.ylabel('function optimality gap')\n",
    "plt.title('tri-cluster eigenvals (L-BFGS)')\n",
    "plt.show()\n",
    "\n",
    "for memory, ls in [(10, '-'), (25, '--'), (50, ':')]:\n",
    "    for kappa, color in [(10, 'r'), (25, 'b'), (50, 'g')]:\n",
    "        s = np.logspace(0, np.log10(kappa), d)\n",
    "        A = (u, s, vt)\n",
    "        lbs = lbfgs(A, memory)\n",
    "        plt.semilogy(lbs, c=color, ls=ls,\n",
    "                     label=r'$\\kappa = {kappa}, m = {memory}$'.format(\n",
    "                        memory=memory, kappa=kappa))\n",
    "\n",
    "plt.legend(bbox_to_anchor=(1.05, 0.5), loc='center left')\n",
    "plt.xlabel('iterations')\n",
    "plt.ylabel('function optimality gap')\n",
    "plt.title('logspace eigenvals (L-BFGS)')\n",
    "plt.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Wow, done in 12 iterations for the clustered eigenvalues. It looks like the hardest spectrum for L-BFGS (and coincedentally the one with the cleanest descent curves) is evenly log-spaced spectra.\n",
    "\n",
    "Let's try to map out the relationship between memory, kappa, and the linear convergence rate."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAeIAAAEWCAYAAAC66pSsAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nSUVORK5CYII=\n",
      "text/plain": [
       "<Figure size 432x288 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAd8AAAEWCAYAAAAn550kAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nRU5ErkJggg==\n",
      "text/plain": [
       "<Figure size 432x288 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "from scipy.stats import linregress\n",
    "\n",
    "kappa = 30\n",
    "memory = list(range(5, 100 + 1, 5))\n",
    "for kappa, color in [(10, 'r'), (30, 'b'), (50, 'g')]:\n",
    "    rates = []\n",
    "    for m in memory:\n",
    "        s = np.logspace(0, np.log10(kappa), d)\n",
    "        A = (u, s, vt)\n",
    "        lbs = lbfgs(A, m)\n",
    "        y = np.log(lbs)\n",
    "        x = np.arange(len(lbs)) + 1\n",
    "        slope, *_ = linregress(x, y)\n",
    "        rates.append(np.exp(slope))\n",
    "    plt.plot(memory, rates,\n",
    "             c=color, label=r'$\\kappa = {kappa}$'.format(kappa=kappa))\n",
    "\n",
    "plt.legend(bbox_to_anchor=(1.05, 0.5), loc='center left')\n",
    "plt.xlabel('memory (dimension = {d})'.format(d=d))\n",
    "plt.ylabel('linear convergence rate')\n",
    "plt.title(r'logspace eigenvals, L-BFGS'\n",
    "          .format(kappa=kappa))\n",
    "plt.show()\n",
    "\n",
    "kappas = list(range(5, 50 + 1, 5))\n",
    "# interestingly, large memory becomes unstable\n",
    "for memory, color in [(10, 'r'), (15, 'b'), (20, 'g')]:\n",
    "    rates = []\n",
    "    for kappa in kappas:\n",
    "        s = np.logspace(0, np.log10(kappa), d)\n",
    "        A = (u, s, vt)\n",
    "        lbs = lbfgs(A, memory)\n",
    "        y = np.log(lbs)\n",
    "        x = np.arange(len(lbs)) + 1\n",
    "        slope, *_ = linregress(x, y)\n",
    "        rates.append(np.exp(slope))\n",
    "    \n",
    "    plt.plot(kappas, rates,\n",
    "            c = color, label=r'$m = {memory}$'.format(memory=memory))\n",
    "plt.legend(bbox_to_anchor=(1.05, 0.5), loc='center left')\n",
    "plt.xlabel(r'$\\kappa$')\n",
    "plt.ylabel('linear convergence rate')\n",
    "plt.title(r'logspace eigenvals, L-BFGS'\n",
    "          .format(memory=memory))\n",
    "plt.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "OK, so the dependence in $\\kappa$ still smells like $1-\\kappa^{-1}$, but at least there's a very interesting linear trend between the linear convergence rate and memory (which does seem to bottom out for well-conditioned problems, but those don't matter so much). What's cool is that it's preserved across different $\\kappa$.\n",
    "\n",
    "To finish off, just out of curiosity, do any of the BFGS diagnostics tell us much about the convergence rate?"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAhsAAAEYCAYAAAD1WzSOAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n",
      "text/plain": [
       "<Figure size 432x288 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYsAAAEWCAYAAACXGLsWAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90\nbGliIHZlcnNpb24zLjMuMiwgaHR0cHM6Ly9tYXRwbG90bGliLm9yZy8vihELAAAACXBIWXMAAAsT\nAAALEwEAmpwYAACjOUlEQVR4nO29d5htWVnn/1k7nVTp5tu5m07QxCYIApJBUDCNigmziGMYnVF/\nODpjVhydMeuIg4MRYVAkGFCUJDl30zQ0TdPpdvfNlU7aaf3+WGGvvc85VafqVrr37u/z1FNVJ+y9\ndlrv+r7fNwgpJTVq1KhRo8Za8HZ7ADVq1KhRY++jNhY1atSoUWNd1MaiRo0aNWqsi9pY1KhRo0aN\ndVEbixo1atSosS5qY1GjRo0aNdZFbSwucggh/rcQ4r/t0L5uE0I8a5v3cbUQQgohgu3cT43pIIRY\nFUI8bIf2tWP38sUIUedZXLgQQtwNHAFSIAM+A/wZ8GopZb7N+34tcL+U8me2cz9j9ns18EUglFKm\nY96/G2gD10gpu/q17wW+TUr5rC0cx7uAv5BS/p+t2uaYfVwDfAH4IynlD2zXfvYihBDfCXyvlPLp\nuz2WiwU1s7jw8RIp5SxwFfAq4P8DXjPNFy/g1bkP/KfdHsQW4NuBs8BLhRCN7diBUKjniRogpax/\nLtAf4G7geZXXvgTIgUfp/18L/JL++1nA/SiD8hDw56gFxStRK9jTwBuA/c72ng68H1gE7gO+E3g5\nkAAxsAq8tToeoAH8FvCA/vktoFEZx38BTgAPAt/l7PMrgU8Ay3qfP+e8dzUggWCNc/JK4AywoF/7\nXuBdzmceDvyL/szngG/Ur1+jj9PT//8xcML53p8DPwr8MorJDfTx/55+/6nAR4Al/fupznffBfwi\n8D5gBfhn4OAa11boa/IDwHHg6yvvS+BHgLuAU8CvO+P+Tr2f39Nj+Szw3MpYfll/pg9cN2nswEtR\nTG5O//8i1L1zyBnHdc699gfAP+rz8j7gqL72Z/U4bnbGYe67FRQr/lr9+iP0uc30dhar97L+//uA\nO/V1fAtwaeX8vAL4vL6mv4/2tNQ/E+653R5A/bONF3eMsdCv3wv8gP7bPmCoSToFfg01mbdQK/AP\nApfr1/4IeJ3+/FX6Qf5mIAQOAI+rbnfceIBf0Ns9DBxCGZxfrIzjF/R2vwLoAfuc9x+NMmSPQU2W\nX6Pfu5r1jcXzgL91jtsaC6CDMkDfBQTAzajJ9ibn3D1B//051GT8COe9m/Xf70K5Scx+96MmxJfp\n7X6z/v+A8/kvADfo8/4u4FVrXNsvA4bAPuB30QbZeV8C79T7vRK4w4wHZSxS4Mf0+X0pygjsd8Zy\nL/BIPdYj64z9L/X1PoAy/C+ujMM1FqeAJwBN4N9QhubbUWzvl4B3Ot/9BuBSfZ1fCnSBS5xj+PfK\nMb/WuabP0ft6POq+/V3gPZVxvQ1Y0OfnJPDC3X5m9/JPTS8vTjyAmkTGIQd+Vko5lFL2Uauvn5ZS\n3i+lHAI/B3y9dlF9C/AOKeXrpJSJlPK0lPKTU47hW4FfkFKekFKeBH4eNRkZJPr9REr5D6gV5I0A\nUsp3SSlvlVLmUspbgNcBz9zA8QP8d+CHhRCHKq+/GLhbSvl/pZSplPITwN+gJi6AdwPPFEIc1f+/\nUf9/DTAHfGrC/r4S+LyU8s/1dl+HWkm/xPnM/5VS3qHP+xuAx60x/u8A/lFKeRb4K+CFQojDlc/8\nmpTyjJTyXtTq/Zud904Av6XP7+tRhu8rnfdfK6W8TSrd5wXrjP0HUZPzu1BG621rjPtNUsqPSSkH\nwJuAgZTyz6SUGfB6lHEGQEr5/6SUD+jr/HoUC/iSNbbt4luBP5FSflzftz8FfKnWtAxeJaVc1Ofn\nnax9vi961Mbi4sRlKGo+Dif1g2xwFfAmIcSiEGIRuB1F/48AV6BWw5vBpcA9zv/36NcMTsuyQN0D\nZgCEEE8WQrxTCHFSCLGEMmgHN7JzKeWnUSvLV1beugp4sjlefczfinKXgDIWzwKeAbwHNUE+U/+8\nV04OHKgeL/r/y5z/H3L+tsdbhRCihTJef6mP5QMoJvAtlY/eV9mXe36PSSnlGu+7311z7FLKReD/\nAY8C/ue4MTs47vzdH/O/PWYhxLcLIT7pXIdHMf11Lo1ZSrmKcqNu+HzXUKiNxUUGIcSTUA/Mv0/4\nSDU87j7gRVLKBeenKaU8pt+7dsrtVPEAamI2uFK/Ng3+CuWDvkJKOQ/8b5QPf6P4WZRf251A7gPe\nXTneGVlEG70b5QJ6lv7734GnoYzFu53tVI+/erygjvnYJsb9tSgW8wdCiIeEEA/pY/iOyueuqOzL\nPb+XCSHEGu+7419z7EKIxwHfjWJ4v7OhI5kAIcRVKE3oh1DurgXg0xTXeUP3lxCig3KTbeZ816A2\nFhcNhBBzQogXA3+NCum8dcqv/m/gl/XDixDikBDiq/V7fwk8TwjxjUKIQAhxQE8coFaMa8XXvw74\nGb29gyi30F9MOaZZ4IyUciCE+BJGV9RTQUp5J8r18SPOy28DbhBCvEwIEeqfJwkhHqG/83nUCvjb\nUEZlGXWs/4Gysage/z/o7X6LPlcvBW7S+9sovgP4E5Ru8zj98zTgsUKIRzuf+wkhxD4hxBUo7en1\nznuHgR/Rx/cNKNH4Hybsb+LYhRBN1HX7ryid5zIhxH/cxDFV0UEZhJMAQojvQjELg+PA5UKIaML3\nXwd8lxDicTpS7FeAD0kp796CsV2UqI3FhY+3CiFWUCvmnwb+F+qhnha/jVrF/7PezgeBJwNoX+9X\noKKWzgCfBB6rv/ca4CbtQvi7Mdv9JeCjwC3ArcDH9WvT4D8Cv6DH899R/v3N4hdQExMAUsoVlI/+\nm1Cr04coBH+Dd6PcZPc5/wt9DAa/jdJ2zgohfkdKeRqlh/wXlDvkJ1FC8KmNDFYIcRnwXJTe8JDz\n8zHgnyizizcDH0Ndl7+nHDL9IeB6lAj8y6hoqtPj9rnO2H8VuE9K+YdaG/g24JeEENdv5LjG7PMz\nKJfWB1CG4dGo6CmDfwNuAx4SQoycQynlO4D/htKbHkQx4G86lzFd7KiT8mrUuAAhhJDA9Zo9Vd/7\nTuqEthobRM0satSoUaPGuqiNRY0aNWrUWBe1G6pGjRo1aqyLmlnUqFGjRo11caEWiuPgwYPy6quv\n3u1h1KhRo8Z5g4997GOnpJTVqgbABWwsrr76aj760Y/u9jBq1KhR47yBEKKaqW9Ru6Fq1KhRo8a6\nqI1FjRo1atRYF7WxqFGjRo0a66I2FjVq1KhRY11ccMZCCPESIcSrl5aWdnsoNWrUqHHB4IIzFlLK\nt0opXz4/P7/bQ6lRo0aNCwYXnLGoUaNGjRpbj9pY1KhR46LGP976IKdWh7s9jD2P2ljUqFHjosUg\nyfiPf/Vx/uZj9+/2UPY8amNRo0aNixZxliMldIfp+h++yFEbixo1aly0yDJVdXuQ5rs8kr2P2ljU\nqFHjokWaa2ORZLs8kr2P2ljUqFHjokWaK0ZRG4v1URuLGjVqXLRIjRsqqd1Q66E2FjVq1LhokdVu\nqKlRG4saNWpctDCaRX9KY5FkOb/6D7ez2Iu3c1h7ErWxqFGjxkULo1kMp3RD3XF8hT96z138+52n\ntnNYexK1sahRo8ZFC6tZpNMxC+O2ii/CUNvaWDhIs5w//8DdfOq+xd0eylgcW+zzpk/UmaY1amwV\nNqpZJNq4DGtjUeO/vfk23vW5k7s9jLH4m4/dz4+9/lMk2cV3o9bYGD52z1nS+j5ZF0WexXTnyhiX\n4UUoiNfGwkHge/ieIM725o1gqO/FSIFrTI8HFvv8hz98P//ymeO7PZQ9j40yC6NxxBehIa6NRQWR\n7+3ZyTjRN2rNLGqshVVd52h5kOzySPY+DPua1lgUzOLiewZrY1FBFOxdY2HEuL06vhp7A2YxUd8n\n62Ojbijz+VqzqKGMxR5duZtV0MV4o9aYHhezCLtR2OimLLd/r/l5e273pqt6O1Ebiwoi35vqIXvP\nHSf5jj/5MPkUN9hWIdH7qt1QNdaCWVQYo1FjMlLn+Z3GANTMooZFI5zOWLzzcyd49x0nd/SmMZPA\nXmU+NfYGktpdOTXciLFpXFG1ZlHDYlqB+9jZPrCzE3d6EScE1ZgeVrPYo1F9O4FPH1viDR+5b93P\nucxiGpF7UjTU0171b/z0m27d4CjPL9TGooLGlAL3sUVlLHYylt0I3LUb6vzAyiDhg3ed3vH9pnnt\nhnrdh+/ll/7+M+t+LtugsbDMouKyOrbY5y8/dO8GR3l+oTYWFUwbDWWMxU4+kLaOTc0szgv87ceP\n8S1//EGWejsbwrrTbqi33fIAz/gf79xTSYBJlk/V/a7MLKb//CQ31DQi+fmK2lhUME00VHeYsqgn\ngJ1c5de+6L2B48uDqcTQXpyRSzixMtiBURVIdjhq7s4Tq9x7pkd3uHfcXkkmidN83QCULC/O0TSV\nZ9N1Is2+cHJ1A6M8v3DBGQshxEuEEK9eWlra1PeNZpFmOfec7o79jGEVsLPGoo5y2X0sDxKe/Cv/\nyi///e3rftZMRCdXh9s9rBJ22l1pFi/dON2R/U0DW+1gnXPgPkvTlPDILLsvPusapFvv39y8cz7g\ngjMWUsq3SilfPj8/v6nvNwKfYZrxz585zrN/413ceWJl5DNG3IYyjd1u1AL37uOfb1MlND730Oh9\nUYW5XqdWd7b3wU4n5ZlVdne4h4zFlJnZJc1ik6GzrkG69VhtLC4aGM3i5MqQXMJbPvnAyGfud5jF\nTk7cF3KUy9luzM2/8M987J6zuz2UNfG2W9T9cNOlc+t+1kxEJ1d2llnstLuyYBZ7575MrLFY+xxs\nVLMYV6LcNRa33L+4kWGeV6iNRQXGWJgVydtueRApy+xht5iFuVGT9MJzQx1b7HO2l0x0/e0FnO3G\n/PvnVdObdApXoJm0T+20G2qHa4gZl8xeYhaFbrMes3DzLDbHLBLn73vP9DY0zvMJtbGowAjcRuy6\n61SX2x5YLn1mtzQLW8ZhD0WdbBXM+d5J47tRfPzes3Z801x3MxGd2i1msdOaxV4yFul0NZ9czWJj\nSXmFYTHbiAJvT9+/54raWFRgyn30kwzfEwSe4K23lF1RDyz2CTwB7LDAne+sL3onYSaavRx6OMn1\nMAlm4thpgXuno6HMfnp7yA21Kc1ik9FQ5r5ohb6tHXUhojYWFZikvGGSM9MI+LLrD/K2T5VdUSuD\nhH2dCJjOHXH7g8uc7Z67yHkhJ+WZiWYvr8wSZ2zTRKRl+S65obKddUOZyXJ1DzELM6b1DIB7v00T\nOpuNyXUyhqkd+evev8eXB/zKP9y+p3JSpkVtLCpoaDdUL05phh4vfsylHFvs8wmn1eozu//Mi/0P\nAdM9kC97zYf53+/+wjmP7UIuPW2MRbaHHyLzgEeBN9XDnl4kAnfBLPaOsZiWXWV5jq+9BNOEzqZj\nMrhLzGIdY/HuO07y6vfcxRdO7l1tbhJqY1FBFHhIqVZJrdDn+Y88QhR4paiob0jfytdmbwemW2Eu\nDxKbxHcuuJBDZ81Es5eZhWF27cifTrPQnz+9Gu9sdeIdXlQUmsXecUMlU7qh0lwS+oJG4E2V8W2D\nTDJpr6nZVzP0rat4vXGd7u7sAmIrUBuLCqJAnZKlfkIz9Jlrhjzu8gVue6CIn27JPnNCRT2sN2lI\nqTJJp4nhXg8XshvKTDR72ViYToXt0CeeYpFgjiXNJUv9nSv5sRERfitgAi72lMCtr896BiDNJIHn\n0Yr8qTQLd3EYV9x97cgnl6y5MDCRU6d3OPdmK1Abiwoiv2wsQJUtNzdJnktaDJiRKq1/vZXEtELb\nNLiQa0P1470vcJuxtSK/FC45+fPFZ3ZS5N7xpDx9b++lPAvz3K3nWspyie8JmsF0xsK9pqY+lDnP\nZr7I5BrGwrLNmlmc94gCdcGX+8oNBRB6wk7U/SRjhj7tXBmLas7Dp48tlcRwcyP1t6D+fbrDIZE7\nCTPRTBMwsFswD3prSjeUy5J2Mny2SN7cnvtkqZfY5ER3P3uLWehF2nrMIs8JPEEz9DZUSBAK3SLO\nKsZijQWP+eyZLQh42WnUxqIC1w3VitTF/97T/4MfWflNALqDAU2R0My6CHLrmgC488QKL/7df+eD\nd52xr00blTENzAMwzar2fEPPMou9e2xG1G6FfikyahKyXNoQ651kFusVuztXvPHj9/NDf/UJFntq\nwjMr7L0kcJvnbmpmEU7LLFxjUa7V1tbzxVquVPMMn6qNxfmPhjYWy4OEZqj+vqn/CS5NjwEw6KoE\nPY+cGQaliftMV/mlzUMExQ21NW6oC5dZnA+hs6l1QwVTGew0l8y1QmBncxCSbda2jAulWqxvLwrc\n6xnMJJOEvkcj9KerOjuOWTjRUMCauRZW4K7dUOc/DLOQUtPK/iIL2SkC1Kpp2C0KyM3RXZOWwtYy\ni3SHQyJ3Emai2cuahY2GCqeMhsqlXW1uxfWfFtutWZzVkX1FbwejWewNZiGlLATuqTULb6pWqeOZ\nhTYWlllM3o4ZV+2GugBgjAXolcLJzwHgS/UgxL2i9Mec6JUMg7nZxiXsTOMPXQ/JDtf82UmcF6Gz\neY4n1D0yrWYx0wiAbQxKkBKG5Qq4ZrLK5fZ0cjTMOasw3b2iWZRLeKwfOht4gkboT9WjJB1jLCyz\niNYXuOM6GurCQcMvTkkz9OGk6ltgjEXSd5lFryTIVm8eKAzINBR3LeS5xNyD2xkNdcv9i/zkGz+1\no3kB4CTl7WFjkegwy9D3mC6DO7cTyDSr1k3h9rfC/3x4yWC4Y5u290n1eue55EW//d6SkG1gVsVp\nLpFSbrjcR5rl28q0XEM+bVJe6Ik1J3n383bbJhrK0bLUZyZvxxjync7q3wrUxqKCEWZx4rMA1g2V\n9It8i3mxWlq5VX2YUJQTP9eHwxXSt9MN9ZZPPsAbPnr/jrsUenHKzeLzZOneXXGlWU7gC6JATFcb\nKpNEvkfoiy3JsxmL5WMQr0Kv6PWdjHGDroWP3XOGR/7s27nPqZh6thdz+4PLI0U0AZtgmuW5Nhjq\n9WnLffzmO+7gG//oA1N9djNwj3m95y7JlBvK98RUkXjlxWGmt1HkWVQ/M7I/HT25PEjPO3dybSwq\naOjQWdC08mTZWGT9om3iPq9fSs4aVgQ/97VzXVmmpdXi9t1kd+q2kDu9wp/tP8ibGj/LDYvv29H9\nbgTGZRH605f7CHzBc4JbSYf9dT+/KWQ62S8uJvrShDZF75O//vB99JOM48tF+1fDHsa5ls72CmZh\n7u/I9+jF2Ug5/3G490y/VOZ/q+E+H+u5f7NcCdyBL6a657NcogPcRjwJ04TOumM729u7C6NxqI1F\nBS6zaAReYSykeujyQUH3F7xemVkko8zCNSDnMgGnYzJHtwOfP26SDXfWWDRT1fSoke7dTmNpnhP6\n07uh0lxyND/OH4lf4YZT/7I9g8q1sUjGl81fb5zDNOOfbnsIqOSFrBpjUTY2UkrLLFLd5xpgXyck\nc4zHWujH2ba6oeIxbH8S0twwC2+q5zPNJZ2orEONMIsp8izg/HNF1caiAtdYzIkurDwIFMwiHxbM\nYsHrlyn/mCiUjVDitbATbqhenNpeHTvNLLxEFVbzs737AKWZYgqh701lsLM853B2AoDO4MT2DMow\ni6QoTLcRN9S7PneSlYG+t51rPolZdOPMHnuaO8aiHY39/DgMkmxbdbeN9KjIdFJe4ImpFkhpntNu\nKKMQV5iF8UpMyyzON5G7NhYVuMbi8OBuAM42ryAgVRQ7VsZCegELoltKzqoKXlB+WM9F5E43IVpu\nFHc5lTB3ugNgkCkXiJfvXWNRCNyCJMvXdbmkmeSAVAmareTMmp/dNMa5oZxrt56xeMunCgHb/Z4p\ndFfVrtxS+1me25X7fl2yfxqRuxenpLnctjLdZTfUOsyipFlMp0MVzMKEyittylSvXS90tqMZyPkW\nPlsbiwoiJxrqQO8uAE7N3EBIph4mbSzEzFHmRa+UnDU2GmqrmMUGRcvN4M4TBWvaySYuvTilgzIW\nwR5hFv/06Qf5+bfeVnotzXPLLKRcn31luWRfroxEe7uMRT6OWUiEMH9Pvle6w5R/vf04j75s3o7X\noHBDlY2FWz257IZSxmIakbs/ZlG1lZj0/I1DajSLKZlFlkvLLMziMMlyosCz2frrMYsj800ATtfG\n4vyGyywWVu+CsM1K+0pCUtJM4sVdujShtY9ZMX1SHpxbroW5AZuhNxWFX+olGzYqrrFYr0DiVqIX\nZ7SFMhb+HmAWUkr+5z/fwes/cl/pdVWhVBkLWJ99ZblkIVNGYkZrMluOTE/OFc2i6lcfh3/5zHEG\nSc7X3nyZHa/BGcMsKpqFK8q6GsW+tslUn84NpX5vk7Fw+o5Mk2fhe2JqgTvNJe3KuY3TnNAX+L6w\nn5k4tjRnVufe1NFQ5zkajrGYXbkTDt6A9BsEIifJUry0S58mNOeZpzs28qmsWRQ367kwCzN5d6Jg\nqrLoX/5b7+GP33vXhvZRYhY76IbqDlPaqMkp2AFjcd+ZXiny582fPMYHvlCEnt56bInPn1ilF2cl\nP34hcKtJYb2VceoYi9lscQuPwEGmJ+9SNFRuxda1JqS3fOoBLp1v8iXX7LfjNTD+9CpTcI2FGw21\n32oW69/jfe2qmiYJbjMwbH+uGUyVZ6E0i+n6Z7tZ+W7orGEn5jMTx5YVuTfnW7e82lhU4Lqh2kuf\nh8OPAF+tBNI4xk+7DEQLmvPMyGo01CbdUJ/7R+ieWnNcbsXT9VYkp7sxDy0PNtyh7c6Tq47fdSfd\nUBltDLPYfmr+n9/wyZKL6bfe8Xn+9P132///5mP3F2NzrpkRuA37XK8+VJZL5lNlhOaybWIWE9xQ\nHb16XWth8fF7z/LMGw/b48lKmoW6DlWmUNYspJ0wjRtqGoHbaHfblahonpWZRrBuIUFXs5iWWYS+\nR+R7pUjHKHA0izVrQ0mbvDdNMcq9hNpYVOB5gtAXzNEl6h2HQw8HXz0IWRITpj0GXlsZC7olsXls\nUt56AnfSh9d9M3z8z9Ycl7kBO1Gw7or2ntPTNWYqDSPLuftUl4cd7AA7yyx6cUZnB91Qi72kJC7G\naV4yCv/62SJyqedMfkku8T2PwNPGYh1dJ81z5jJtLOQy5NuwkjZuKIdZJFMyi36cMdcM8MSoMGsK\n3Y26oRzNwomGmmsqN9RUobPGWGyTG8bc97PNcIoS5WoBEDhtCNaCYSKNwCtFQ0V+cV/ka/azKPSN\nmllcAIh8j+uEqjLLoYcjfPUgJOmQMOsRey1oLTAjV8eWFihpFuslCMU9oBDOJ8F2aWuoPr9rTeYm\nE3cjvSHuOa30lxuPzgLbbCxO3gFv+8928uzGhRsq3AFjEWd5qb9Imuclo9Adpsw11crcdcOkWU6o\nFxOwvjHOcslccppUhHhI6G2DyG3cUEk5GspoFpMWFqZMRyP0rfvEneQMs4izvGRwFnvVaCjtHp2C\nyajvFAZmu3ItYmssgqkKCQaeN5ZZ/MtnjvOc33hX6fiNxtEIvZIbqsQs1nFDhTpyai/XQRuH2liM\nQRR43OBpV8ThwlhkSUyU90gCxSzask+WFiutTUVDpVqYTAaj77kfq9TMX+uhtMxiAyK10Ssero3F\ntt7In387fPQ10D0JqBWu1Szk9ruh4jQvuSfSTJa6vA3TfGwoaNUN5U7Ev/WOO/iFt36mtJ8g69PM\nuxxvXK1e0Me7pbBuqAqzaKx9n5j7shmOuk/SLGexlzCvy6u7rqUzE5hFp7F+QhqU2fX2M4v1NYvU\nybNIMlkKh/70sSXuOtVleVAcs+lR0gj8ktu5rFmsHTob6cTOzTT6esNH7+Pb/+TDG/7eVqA2FmMQ\nBR7Xi2PIsA3zV1o3VJrENPI+qa+MBUCUFoxgc24obSSch30cDEVuhWuvGAHu1cyitFK694NrrmyN\nsbjhyA4wC1P0LlXH3h2m1g0V7oBmEad56VokWW7bupr3x4WCuhncUGZuH7zrNB+4qxDJAfbnSqc4\n3r5evdDdhsS8MXkW00RDmYVLM/AJ/LIwe0azh6sOtNWwnXOz2IutEUmzQuA2EULruVb6JaO8Tcwi\nLdxQWS7XXFhlWZHBDapSr4G59r1hecHg61yboge3VNFQU2kWuS0vspmIw4/efYYPVe6znUJtLMag\nEfhcL+5HHrwBPA8vUA9Hng5p5X3SoAPNBfXZrDAWtjtXxTVla8mMNRb6IU/WrpVjNYvG+r7oe890\nS99BSvjTr4KP/J+J37nzxCqXLbRss55tDZ21xsKIqBkt44baDmZx17vVj0ac5qVJK80LZpHlkjSX\nNrrHFXiNC8IYi2oNoipz3K9zLE52blAvrBPEsCnkJnTWSajM5ETN4s8+cDcv/t33WpdoM/TxRdl9\nYiKhrtivjYUzWZ7txRyabdjPb5RZuOdou0JnXWZR3WcVVrPwR3WbFc0ounF1wVAWxI3AXTW6k8YW\nBir6ajPJtYu9hGG6fkLodqA2FmMQBR7Xe8cQhx8OgLACd0KTPllQMItmUlTlHB86mzOrxb+xD4de\nXVt31ASYm3ga4dIwCzuZ5SlkQxiOVhA1uPPkKtcenpkq/O+cUWEWrsAdym3QLN75y/DuXyt2n5WZ\nRZpJq1lUk8zcidJkcAdjQmcHSVYyQAAHpGIWZ2fVfbQtbiirWaj7R0pl7CZpCHccX+H2B1cKZuG4\noYxmYcT/K7WxcNnV2W7CwRn9PDgZ3B3LLDbihtouzUKNYXaKXiKp1izG3feWWTjX1TRLCrzCjWTc\nUFWjO3ZsaRF+vRmB2yRF7ka3zNpYjME+0eMScQZx6BEAlllkyYC2HCCjmcJY5EVhwcKHWX4gDG2f\nGA3l/p6Aos/v2kLiIMk4vqwmXHvTmgllQvnvPJd84USX6w7NbFvobJrlvOw1H+L9d55yjIUaZy9O\nbejstjCL4Yrdl5RqNeyuNpNcRUMp0VeHgrZH/fVpplaVJrw6qehR1eu7H2UsVmcfRiJ9spXtc0Ml\ng1XyXFLtB11dVAwSVdDS1INqhr6N4jGTn5mQLltoAWV2dbYXc3BmlFlYLW0dRlpyQ63DLAZJxgt+\n8928546NGdnEcUOZ7UxCmuU2dBbK9705R1V2GZjyIPqzSZaXyn2szSzkOQnci/1YH1NtLPYEHia0\nuH1IrQi9QD0cWX8ZX0hk1CmMRTaqWbj0Mk5VGGPoi/E37ZTGogidXZtZuD0JRo3FeBH9TC+mn2Rc\ndaBtJ46tLvex1E947+dP8acfuHsss5gRajKPtsVYrNpz4PqZkyy3TaWkVA/gCLOorCoDR7OoFqxz\nJ8I8l7Q0SxLNWc4wS766DcZCu6HuuO84b7/toSJ5c0KWsLkHTXJdM/Rs5nHhVlGfOVDJnRimGb04\ns26orOSGUvtb777pVQIJ1sLJlSF3HF/lsw9NZsTjMOqGWkOz0JO/ZRbZqLFw2WXmaBZGyC7CYdfP\n7E/0giP0p0sCrMKELm8XK1sLmzYWQojnCyH+WAjxOP3/y7dsVLuMa6Qu83DYGAsdOruqhaVoFloL\nALRKxkLdPNfEn4clFXpr/JnNYEJD+HRKY2EE7nWESxMJFbk9F4wImo2fiM22WqG/bczCxLu/+46T\nZAP98DvMomOMBdtgLOIVew6qVYDdlXA3TsdkJLt5FpXQWee7g1RVYzXnPM0lkVD7DBtNzshZ8u3Q\nLPQ1bcoBx5cH1oA1Ag8hRhmomTitsQgKzcJ0ijPnaKFtRH513xrGYZmFFrg9UVQ+WC/RrKxZrD3h\nmTFutCyGm2ex3n7SXOL7An9MCRfjhuonFWbhl5mFdUP5a0dD5VoPs7WoNuhKklKyZIzFecYsvhv4\nCeDbhBDPAR63JSPaA7g6u5c+DRUJhWMsusqt4EWFZtFx3VD6pv4f6a/Ce39DvZbkNAKPZuSPX+EY\nI5EOGKYZn7pvceyYqu6FSW4oo1dcfbBd+I/1hHJmaZl/vf34yHfMwzitSLcZuPWAeiu6Z0VWJH4Z\nN9SWMwspy8yiEp3m+tj7cVE6u90IiAKvLG5mFYHb3ZZeMRujmOWSiJRMBDTCgJgQuR1dALURbIrY\nsiVQ1zLyvVKwBRQrUpOJ3XAWCAWzUL/3dcr1nszkXWIWWU4j8BFCTDUBTgqdXeon/MG77iyVV1m0\nq+iNTYxxmiNEIbqvtQpPq8yi5IbSAvdwvGaRWTeULBUSnLTQMosLFQ21cYG7nxTl4bezxPsknIux\nWJFSLkopfxx4AfCkLRrTruNa7ueh6ErQtNLz1cOR6/7bftSCaIYMn3ZeRKEMkwyPnIPyLMTqdcss\nQm9CNJRhFj3+/pYH+Zo/eF+pbpFBNqXAfe+ZHjONgMOzzWLlqyfKu4+f4Rfe9pmR75hthf50ZZY3\ng5JGYFrTOm6oljEWW80s0qHKRchGhcFBnJeMhWIWapyR7zHTCEphk0mm3FC23If+rtuH2hiNNM9p\nkJB5Ec3QJyEgd4zFK/78Y/z+O+889+PTbqg2Q5K8OJ7AU+Oc5IYy+RLN0JnksjKz2N8uhw8b4fuQ\no1kMk8yeDxUOuo7APSF09l2fO8H/+KfP8ZkHC5eTMU4bNhZaFzD9JSZ9X0pZSsqD8iJsdaxmkY9o\nFsM0Lz07k/rXm/vFtNrd6DPmZs+fV24o4O/NH1LKVwJr16s4j3D1K17PZd/zl/Z/L1QrLKmjibyo\nCUIw9GfoyLIbaj8r+EKWVrKRv5YbyuRZDDi1OkRKbAMiF1WBe1I0xL1nelyxv12uoqlLQuTJkBPL\nQ5Is52t+/32883Mn9LYdZjGFSLfUT/ihv/r4hurxG1Z1cKZBkOhzpt1Qw2GfgIwcjwbJpE1MjX/5\nzHHe9AmtO5nM+DHMYpBW3FDDrGhkE3q0I78scOuwyaAysYxLvFTMIiH3IhqBR4qPzIpj+9T9ixNZ\n5Iagt9lmSJIWzCLQQvwkN9Si1Sx8vEoymfnOTDPA94Q9B2alXzCL3C6GgFKE0CT0S26ocog5UKpn\nttQ3LpeNTYxGcG6EXmnbVZh7fByzyJxwaqOz5Lkkl4xUqVX7E+szC7soMyxsY8zCzZ7fswK3EOLK\n6g/wicr/bxZCzG3vcHcG4cwBoiM32v/9UD0cUnfJ8yIVUjgIZpnJTU6Dal5/2FtUn80KIaoR+LQi\nf4LA3bO/zUrmxPJo+Kih9+tl5t5zustV+9vlOG5H4O4nGZ8/vson71vktmNLeoyFsZhGs/j4vWd5\n2y0P8sn7pi+OZx74Fz/6KB3Zs+MByIfqHPaDOQKyot7RJvHH77mLV7/ni3rH2k04zg0VT3ZDNXyP\nThSU3FCZbX5UzuB2r6uZDFPjhvIiGoFPIsvGYpBkU/V+WBf6uBoiIcuSwvD76zCLbmEsQE2YVc0i\n8j06kW/dMGalbzSLJJPWzQpMlWhmmIUnyqtjs88TKwWr3qwbyojIJmptEgs397jvC4KKZuFeG2Ms\nzPkZGw0VrB8NZd1QWgzfKLNY3GVmEUz5uT8FJCDW+IwEXssFxDAMfF3uw0vUxBNEqnlJHMwwQ+Fu\nArg8UgYlzxJ8NLNYS+C2Gdx9VvQNenJMb15zY9qaP2MegDyX3He2z3MfcYR7TzsVcfWE4uns6E/d\nvwgUqxMzwagVz2gF0ipOrRhhevobdqBv7hc+fB7/E3rbmlmY1X8vmKeTLioj4s+oj2Q5QhShjdPg\nweV+UT3YMovRiaefZCWj241TWxE0Cjw6Db+cZ6GbHxVuqNxux27TSe6LhGYWoceAoBS63N8qY5EX\n25BJz94nZpwjxiIti9VNfSzVyc8TEPgenUYwwiwW2qFNShtWmEWSSfjs38Mn/gK++XUjwzXnar4V\nlq5FPIZZnIvAHfrK9bvW99diFitOiQ9z/OY93ysL1EW5j7WjoczizWRwb/S4ysZi55nFVMZCSvns\nca8LIRpSbkcW1d6CYRa+nniCSMWfx8Essyza2H2AK8IVSLBipjUWkc9yP+H+sz0u39cuNm7cUNmQ\nro6hPjlGs6gK3ONuluMrA+I058r9bR5Y7Duhs+omMy6eW7SxqJYnaUzJLEwXNWssTn8BXvti+N53\nwPxlY79jDNP+oLhdZDpEAFIzi0GwANyjzklDGYtv+KMP8NRrD/ATX/7wieNxIaXk+NKQI/Pqmp04\ndYrDYA1m1Vi4x9mLU1uBtRH4dBpBpZBgpfmRviauS6DMLBJyXzGLVXzIB3aMgyS3TPJcILOkWMHF\nRU94w4Cq7koz1rHMopJkBiok1rCrM92YVuirrG9tXBSzUNuwiWb3fgA+9w+qUKTnl/bfTzJCX9Bp\nBKWIHjPOE64bapPMwmgIkb+2ZmGun++NanXjmEVxbosMbhPhNBWzcBhb4HulsOxpYHIs4PyLhgL4\nOfOHEOJp57itiRBCfI0O0329EOIF27WfSfBDJfQFqZrUwqaa7ONwjjl6pSYwR33FPmRa3OiNwKMZ\neHzyvkWe/mvv5AsnnQqzTk2o4UBt/8SYPhRmFdOy0VCSxeUVbr/zLvuZe3XY7JX72zqOu8wsjLH4\n5H3K/TRwCqEB5WJo7iTTOwN/+HRVLRY4tTLgyeJ2+uaBOn0nrDwAZ7848Rwa90crL46311PHK3Sp\nin64oA+2MJb3nenx+eNrV+R1caYb20qp3WHKT7/+A8U5cIw6wCDOStE7vTgrRYZ1omJVbTKjA6f5\nUTLODWWYRSZpkCC9iGbokeCPsJsqs3j/naf4g3dtTPSWacyyVIsXLy1K5keBMmrViBszVlezAFWa\n34aCOmxBMYvCDfWKxtvh/b+rjEtFs7AlMBy2XEU/zvi68AP8WPonluXA2sxioy4XE51kCz5OdEOV\nNQRwmYVrLMrMIvCLZklxNvrsTNIiEuez4RSRY//xLz/Gr/3TZ+3/u+2GOldj8XYhxMuFEN8KvGgj\nXxRC/IkQ4oQQ4tOV118ohPicEOJOIcQrAaSUfyel/D7gFcBLz3HMG4YfKGNhigYaZpGEc8yLLkmW\nW0t/xFMTsXTi+qPAs/kPAA+4ArZTbTYeqM+MNRb5aGburW/8VQ78xXPsZ+7RYbMquc4R0HRl0kgb\nizuOK4PmllgGrVmMaw154nY4fqv6AVonb+H1jV9k9uRH9fb1jZtOJpnGMLWc6DGpj91P1bgHxlg4\n52SQ5FbonAYPaVYWpzmrw5QoM+daQp6VVtrKDeUwi2Fmz0kj8Gg7bihzPkKHWcTj3FCWWeREpJZZ\nJASg3YDmXqkaizd/8gH+8J1fmPpYQd1ny6geJCLp2wko8MaXlDD7PtOLS8XvAk/Ych8mKANgpuGX\n3FDP5wNw25scZpFZzSL0PZVnkRYRflUMkowvE7fwrPR9ZWYxxlgs9jepWejxm3ENU5WdXz0XhVtp\nNIPbsD7fE5ZZpK7bSgvcrkZUDRSoInbdvf76Avct9y9ZLwCUBe7zilkIIV4DfBXwzcCjpJQ/s8FN\nvBZ4YWWbPvD7KMNzE/DNQoibnI/8jH5/RxFoZtHI1EQXtRSzSKJZ5nQDJDPJHBLGWOiJQa+8vupx\nl9rtlSY/tw/B0DCLUTdUmquyBIbyx2lG2D/BYc5al9d9Z3r4nuDShRaBLxyBW7uhdJKYeUgssxiz\nOipR6d5pM0AAclM91STXGb95xVh8+tiSnRDNiraRF4ZSpgPSLCfQE/owWlCbc1akgyTbmLFYUudu\nmCoD3hGOYc7i0TyLfG1mMbqqdDK4U3Mex2sWDZEgfRMNFSD0eTIr6l6clc5zL8lYjdONFYnLE1ak\nuh+9tG+veTVxzIypEOVzmkHhIvKdtqKJwxZaYWDdJWd7MW2RQNzTzMLkWRjNQhunZLKx6CcZkadc\ndO7qOFnLDbXBidEU63OZxW/88+f4xj/6QOlzpcm/otWZsuSHZxtjNQtfN0sqmJxzDtbTLLTAvV5p\nlO4w5Wy3uPfP9hK7n/OKWUgpvwf4adQEflwI8Ucb/P57gDOVl78EuFNKeZeUMgb+GvhqofBrwD9K\nKT8+aZua5XxUCPHRkye3rmib0SzMRBc21MOZRvM0RUIy7BWN6+WiOr4ssVpGw/f4wWdfx4f+63OB\nMp10XS6pZhZmdXW2G/MPtz6o3rP+cuMCkQgT4dNXk/bpbsy+dmjFtqzihopIbb0fGNUs3Po2pRu+\nd6o01rSn9pcmeqVjjUVxLEmW83V/+H5e817lmjITZJQ5zCId0ksyOjrHYhjt08Pt62NWEWbLm2QW\ncZYxg2N4q8YirjALJ4O7EXglF0zVX+052dHDiZpFivQbKs9C+tZYuLkGLrvoxxlSbixwQOQpy6j7\n0U97pZVuWAllrU4wjbAwFpM0i0bo2VpnZ7sxTRFD3CXQ5SpcFmITzQwzjEeNRS/OCD1JQFpiDG7o\nrDGWm3VDxVrgLphFzt2ne9z2wHLJEI/TLMz5M9fl8FxzPLPQ58t14aptTW7Pat1Quhjleomvq8O0\nxCYWewlH5hr2mHYa5+SGklL2pZTvk1L+lpTy+7dgPJcB9zn/369f+2HgecDXCyFescZ4Xi2lfKKU\n8omHDh3aguEoGGbR0iGfkTYWWaQihfPekr2hF3QPA7KY+My9vD36SQ5kaiVuCgqWmUWx8s31w3Vq\nNSbLJW/46H38x7/8OEv9xBYgcxvvWGOhJ++k9OA6NNeUhBAJl8w37f6qzKLh1LdZi1mkA+WOSxP1\n/8llNe7FlcIQLPYS4jTnrlOrpX2FqavXDFXjI13qI9bGIo8LdjDPKsN+RbO478Pw8T9nHAyzSHOp\nak7hMovE1j1SYyprFt04rTAL3+ofqbNiB+NyGXVDVfMspN+gEXokBHjaHej66kvGIjG1iKYUvnOV\nBDrQkWN+2rdMKRjTM6Eam2+ihUBPcrKckQzqnjAT09leQoMYkm5psnRX1Vmer1nCZpBkRF5OINNS\n/oTr0lsdpuS5LPIsNhkNFfgeniiaXQ3TnOV+OW8GCrcQjGoWR+caReisNS7CMjE3ktCcg+nyLNbO\nSRmmaiHjJuIt9WOOzDb1+3vcWAghQiHEDwkh3qh/flAIEW7X4AyklL8jpXyClPIVUsr/vd37qyKM\nlDU3+QHNlu5TrY1F1jtrV5ezqTEWKdmJO7jRu59Lu0qkaoY+jcArr5STPiYiOY97RL4qI3CmG1tK\nvjpMVeaoEzs+THMbCpt0lesrznLCkv/YMItCszisVyZqG2VmEeqHC6rMQhPAdECS5QidVJdpZnFi\nSRmJU4tL9itL/cI1BthMX09HlC3LFjId0B0WFWeNsci0+2KY5vxl9Ct8f/76cl7JR/8E3vFzjMOD\nSwWTWBmka7qhBkleiYZyNQvfFsfrxak9lyYeP/K9Nd1QBbMokvKEMRbOpO1GRJnvTh1Sq69rFqnS\nM17muKE8MVJSoprn0wxdN1Sx0h26zEKH32a5ZHmQqHIssXJ3JtWkPJPBvUZDr36cEQpJSFI2Fs51\nObkyZGWQkkvJU7zP0I6rDggVJm6+8zN/dyuvfd8XS9uK7PiVwTfn/Ljj4nU1i2pC3eogxfcE+zsN\n64osDLEoueGAUZF/DKy7N1B60lpNmcx90U8yp/hjwqHZBkJsX0vatbBRZvEa4HeAr9M/vwNM7qiz\ncRwDrnD+v1y/tqswAndLxMTSpxHpjO6GZhb9RYZpjk9GO11UX8oTEr1CnktPqQeov8hCO6y4ofq2\nzpRM+rY72YkVldEN0I9T20tBCGFvNGMsUu2GMisq0HHzFc3CJ+foTBEtXc2ziALP1vgpiXSmAF4y\n4Ew3piPVcWVaK8l1El0aFxOzOcZ7z/T1vjIV06+T5M7IOUiHutSHNnqROQ8D+52DYonD4myZjQ1X\nJvYsd0ulrAyStd1QlTyLnpPBrcI71WTadbSF0AjCzsM+LnQ2y3MaxEg/UkUd8fFkWb8BWB0Wx9Xb\nqLHQxkfoopZB2i9dy6AycY0ai+Lxd1fErmbRCHyGqQrzlVL3SE/7REIZkMQxLKGnM8bXELj7iTIW\nAKnTkrhqLBb7MftY4a+jX+KZ8btHtvOGj97H037t38hyybs+d7LUpdB0rjPnYehMuA85i4mxmkVW\n5FnMNAIt8BdsEQpBPMnykgsX1GLCfO7YYp/bHigWUG65j/VKo7j5PeZZWuwlLLQjmvqa7DQ2aixe\nAvwtcB1wA/BmlMi9VfgIcL0Q4hohRAR8E/CWLdz+5uD5ZFI3vCGyUQ95Y0H97is31H6WEagbQGQx\nmXbTzCan4F9/Hv7vVzDfCituqAG09wPQJOaag4q1nFwZWmPRHSp3iVn9RL5a7VWNRZxK58FVN6OU\nslRt9mhHbaMTFTfcOL9racW9pNxoD51Z5OTK0K7W8xFjMZp9e2pVuZoGSa5WssMVchGwQgvSgfJh\no8NTdW6F0SyUAc4JSSvGYlnpI2MyvV1msTyGWbiaRD/JShOAqTrb0EbTlFbpDVPHv+24oSrRUEIU\nfyeZJBIp+A2EEEgvwM9HjYUbomlen9ZY5Hqyjdpq0eLlsVMbyvSVHjVkBmWBu1ggqJV5MdnGaW5d\nZ0Gu7sm2F9vQ0RKzyNZhFklG4KkxmufD7NOc2xMrQxZ7CZcKxSiO5ftHtnPLsSVOrgyVNpXmJZ3H\nXTQ1ApVrYsbvLiaqgjUUBmRlmDLTCGhHAf0ks/kU7rktRUONSW78tX/8LD/wF4XE6obOBt5oKRYX\nK0NX2I6RUrLYi1lohzQm1ZnbZmzUWLwP+IAWoO8E3g/8+2Z2LIR4HfAB4EYhxP1CiO+RUqbADwFv\nB24H3iClvG0z299qpDp/cYjjdWuqh5TBEsM0t5FQJ+UcIk/J9OTZiU/BQ7fCqTvY1wxKyTUkfWg5\nxuKQMhYnVoa2vaWJmgkqD7CvjUU+UKt1U6MGCndJlksbmQVw1byaIK4/MmtvOFNl1PW7unX9+4vK\nWHS7XU6tDu1qPdOTlTEWmWssnMn9vrM9BmlmjUUWzjAgQmQx3TglEBkSgQzUsbvMwkOFoC71E06b\nzHZddoW4qPhrcHxpYHt+rAxSK57rAVpjMd8KGTgC91wzsOU+zIM/o91Qq8O09KCb39VyH3PNsJzB\nTQK6F4r0IjwykLLCLEaTv8Ym6/XOFKXmNU4tqfPQ7syqF/KkNM5qz4RRzWK8G6rMLDyGqVqZ+2SW\nHc2KmEyXKI+qiwzDLMYI3IM4IxBqHNKJnouz3OppJ1aGnO3FHBWKLdyXjRqLBxfNgkJdM/ecugZM\nMYvCDeVGW7lBC+M0i9lmYEPVywsLFWLuahbmeXNZ+b1nejy0NLCierlSwtoCd7WVbTdWCaT72mFJ\nR9pJbNRYzAO/KoR4txDiPcCvALNCiLcIId68kQ1JKb9ZSnmJlDKUUl4upXyNfv0fpJQ3SCmvlVL+\n8gbHt21IhC6zISL7mojUQyqHqyVj8aA8AHlqffqt4UlYvAfyhEsafZYckY20b5lFSwy57pBaXT+w\n2LfMQvnMZWmiSrIcX7sh8sGoG6roKSytEA3wvOsXeNsPP53rDs+UmEXkq9U0jDILoQXuPBlwajUe\nYRbSFCosMYvCQN13pqfcUKFnjcVQhopZDDNCMqQXQqgmC9dYBGREpHzgC6d5wi+9Q1VqNfWehmVj\nsTpMWRmmXHlAGZ213FBzrbAUOntj4wxPXP03zSzUBGFqID24NCiV0QA1CRlDM0wyhFAGqBoNZY2F\nr91/WTJZs9DfdetRSSm58/gK/N4T4WOvLR3vg2fVdZ+ZVfehyJKRkhKugG8WB2YVPSJwO0l57so8\nl2ryajoVgdtiaKOh3DyLNM/XZBa9JCO0xqLYXpLl9nyvDBKW+gmXaGZxb7ZvZDsPOiHS45iFMWBR\noMq0G2MyjlmYMGNwMriNsdALhm6cjmUWcVpeaLnPzrHFPnGWs6yvcfnaFAK3lJLX/PsXOeGMzXVP\nLvYS+zwttFTezvmgWTwNVSLky4Cn67+fAbxY/+w6hBAvEUK8emlpaf0PbwApOnPaMRZeQ01KxF2G\nac5BCmPh5TGpfmjag4dsM6QrwiWWei6zGFhm0SDhwEzE0bkm957u2ZIMvbjihtLMItC9H6TLLJzI\nFPNaGhfGws9jHnXZPM3Qszec+z0YFelaRodJ+8oNhW5RatxQ2r2SOaGzrttIGQvthopXyaIZhkR4\n2ZBenBKQgh9AYIxF4YbykISkfFD7pH/97Z+jrwV9yzA0jD/6Kt072gjchhWqaChVZK4d+aV+Fl/P\nv/DK7q9zZOU2O/ldf0S1mb3tgaVSGQ1wSlugJvlGoKrUFswiV8xCl7fH04w0TyYyi0cln+bl/ltt\nsyGAd37uBF/+m+9UEWkrD5aP96y67vPzC2oXeVISYatG37hiTMvYauis28zHnWxB5R20HGPR8YZk\neV5eoBidTDOLU2cXRya13jAj0JqFW7J9mOY0Q9WDY5DkrAxSLhWnyfB5IJ0dyT0xia1xqvqAuy62\nUuhv4Os2ulrgXh7VLFyB29z33Til0wgsS+072f62B3clKc+cgyxXeVcmBN78dl1WoS9s0MRDywN+\n8W2f4Wv/4P12bKsVZuHW5TpfmMU1a/w8bGuHtjlIKd8qpXz5/Pz8lm7XTDixKKKJRMO4TboMk4xD\nYhGAB+V+hEzJ9Yq+s3wXSHXxL/EWi4lUSrX6MsyCIZ0o4Ir9LW45toR5zntG4HYicYZZTqDdUFKv\nsE0dfygmtSyXJIljnDT1bwRlzaJsLAr3xfHTZ2hp40A65Ex3yKzQNY60W8QwCzfzWolxIa3Q594z\nfS1w+zBcRoYzxASITAncARl4IUIXaMwdZuGTE4qUW+5fwvcEC+0QYcTteIKxOGCMRUKHAStCsTXD\nLCLfoxn6Os9CMw1fHcvzTvxfayyaoc/1h2e47YHlQuB2Q2cdgbsVqsrCllmkGZHIEDo4Al2Mkiwe\nayziNOerxHv5r+HrkEsP2Pc/fWwZn3JUm8HJs+r4F+bUvS7ytFi9eqN5FmbC3Kf7VLiahVdlFo7A\nDbDcT1SOhcYMA4ZpTi4paRZJVjCLP3/P7Tzpl97B333imD3GOMutG8qTSakYXxT4dhEzSDIuEadZ\njQ4jKU+O3WFqV+u9OCOX5dyV3jCzZXEiPbEOLbMoFk5FIUFHs9Dnqx9ntCPfuqG6w6zELo1xMeMy\nz6Ypm+IK6cZDUNUspFRjMJGUxxb7NhrPZZyKWRhjofqjjDMW77vzVImdbDU2VKIcVVl24s+FUqJ8\nHDLthkodZhFETZVsZZiFWCIP2yzRwctTK+AZ0RvgMGfpmkkqiwEJLUWzm8TMNAOu2NfmzhPFRKhu\n1LwU4ZGkOYHp/aAnzVJkipO85wqJJnHOZRZqJVZUdXX9rp/+/BdL310dZsx6pvhh2Vi4PujFfsL+\ndsQV+1tas8hVf4GkjwxaDAkR2ZBunBKSIfwQz4/IpbBjNAK30SwuXWiyr+nTNPWlKm6oB5fUavNK\nbSyW+ymzos+SuS2NsQg8WqGi8raMiq+O4VHdD/IoivpMN106x20PLNtJ2JbH8D2r9SgXm2+3WToX\n2g1lIurIUttNz/dEKUTSTMaXPfgvdv9fOLmKZ4xFXtYyTmrNIooaZHgImTg+dDEmz8IwC20sKtFQ\nrmbRGGEWqcqx0GiL2Lp+3KqzeZbZDogtEbMyTHmX7ptiJnTDLEInMc814oMkox9nXCLO0GsdAcp5\nBeY6Q1Ed1hhpKSXdOLV6kwr9zSyrcifTpMIUoGAbvVhdUxvkEKdl46KfF7Pfqt537GwxRsMs3Ei7\nwC+Yv1uC5t9u1/qgXkR4QiVDmgTFQrMoM7Y8l3zX//0Ir/n3L7Jd2EiJ8vUguUBLlEPBLBKvYBah\nL+jRQCQqg/tysYRsHybt+QgkyXDUZ3tAKj/sUj/hoK/fj2bIvJCWiJlthFy+v136jnGXlNxQWU4g\ndejk0HVDlQXuNM8RLrMwRQUDX+kZWT7WDWX9rsfut6+LbEh3mDIjBupqZypKQ46pDbXYi5lvh+xr\nR9x/to+UkuZsA7oDZHMfQxkjsph+nHFQZOCHBL7HkHCswA1w1f4O/dVFMKe1YiyMi+FK44YaJnTo\n8wC6Em6WlIzFg05S3oyXcVLO0fTh24evA74XgEdeOs/ffvyYnaBCy+6ETbIapLk1FqZMhGGVnjYW\nkc7Vcd1Q+ztR0ec5LjSB6069A/jvANx1suswi3KzqdMmCdKPyIQqJ2JWqY3AGykkaJmFbpdaFbir\nPaXNdkAzC9dYMLCTv5sI6mXFPWC6H5pyIUaLCfTxRNpYdBpGlBa270s/ybhUnGbQfgJgcoLUuB9Y\nLOfSQBEc0E8U0+g4xmJZJ7UKoQTuPJclJlUWuIughXbk2/DpXpzZJZ/rthpYY2FEfsXK3QZmBbNw\nNAvH7eVWAHjLpx7gRY++xLYrODzb5GwvsQEj8zoaqhqscLanCmiO67K5VZjWWPw0Kgpq7fz0CxiZ\nCEBC5hXMIvQ9ujQRSZcTywOe5i/DzGGSU+q0ZgN3MhPQmGMhU773xV7CfScf4mbgTOwx4zVoMdTM\nooWLro7GKfzlSrMItbHwdJKcK0y6tNqbwCxA11ByvgeUShHEy6psSkyAnyqNoaOzon1UJIphFiJz\njUXCwZmIgzMRnz62RDtSpa1JejDbYojEy4ZKOPVyhBfie56KknKYRSgyQh2Bc+WBNqcGTg/xihvq\nwaUB+9ohc001qaz2YzpiyCKOG0obxpbuiW4e4I6fsiRneEv4PL5n+Gdw/0fh8ifyyEsVK7nlfqWT\nmIfcXAPQE33o03Q0C2s4tWjfaDTtGPo6QXG2GdhJoZ8UxuKK1Vtg5SHkzBG+cHLVTq5VN9RwqPfh\nh2QixJeq3lLDywn+5WeYT184Ns9iPLPwymG/QZVZJCMCd09nnNtEUM/Dz4vJqkWM7wl7Tsxq2Reu\nsSjYrdtRsh8nHOUMd7Uvse8buMzCGGeTOGiM74ye5BuBZ11Wl863OLbY53Q35tBsY6xbyWUWrdCn\nFRbMwtUDff0sVo2FYeXGoPmeGNEsjMAN6vk0VQXmmgGf1nkZ3WFKJ/LZ34lY7MVW5zQCd7Ve2mmt\nb5r2AduBaTWLlwEfE0L8tRDiO4UQR7dtRHsU1g3lMItW6NOXDeSwy+0PLnNpsIKYOazKUQP5oCh/\nwdxlMH85s7FKcFvqJ9xzXBmOjx4bkHhNGsR0Gr5dGUNR9bIUOqv95aF2Q3lruKHSXJaERNOAx+1P\n7JYJMfs0D02u60KdEgfwcjW5t7WxCEnVRJCPMRb9mIV2xIGZBrO9e3ll/3/R8TJlrELlhvJzZXya\nvmYWnlDMwhiLWDfo8bSx2N9mX+gcS0XgPr484Mhcs2hOpHumn8mNsUh09I4yXG40VMtLGRLyx8Pn\n0Rct+ORfAcoNBfBJ3QI18AuDndiMZxXppdxQant5WmYWhbFQq/9m4DHbCEp9npsknJRzeEi4/a08\ntKzyUMzkWnVDJUM9MXsBuQgQuTLe14en4IO/z/WrHyrF8luBuzNesxjPLIowZFezaDnMwrisfF8Q\nOPdAWwzZ1w5tBrRhGIYphaSlMvmm78sgyfEHZ4lESty5RJ/j4jjGMQtQBteEnBpmETkVE67YrxZh\nplDnOM0i07lJ/SSjFQVlzcJxRRrjYl1rXjka6oHFPodmGxyciUqahSfUZ6ybOC8qVj/qsnnuP9un\nF6esDlJmmgH7OiFnezFnewmdyCcKVM2ranFF05Ds1JjGaVuFqYyFlPIHpJSPR/Wv2Ae8VgjxASHE\nrwghnqGrxV7QSLWxyP3CWFyxv81AtOiuLvHZh1Y4wCJi9giZJmzSXfkuXAmzR1UYLaocRr+rJrP3\n39slFg06XkIj8LlCG4vAExyaadjQ2cDxI8dpTqSZhZ+Ybn2jAnea5RVjUWYWgyQrxaWb/Zo8CxM2\ne9o/pCb3YUJTZ3CHpPSSjFy7oTzHTbLYS5hvhRzoRDye23lh/h4ukccVswhbxAR4mfJ7N0Su3VCC\ngXSYhTEWQm3/qv1t9vkOzY6rmsWAS+YLY5FpY31G6qi1LGaYZkS+ntidPIuWSBgS8tAgoOvN2bDP\nuWbIwZmIe0537bkBbSzSwmXRDJQYaiZG47cX2li0mroVaTK0GsdMMyhV5W2ImNvzqzgWXAmfeTN3\nnVT7fPSlKjR2MBjY8ikAsXEv+iG5CPA0s2j56piaMh6bZ7HQGnVDBZ4gdwRuN88C1OLGZRYtBiOa\nRegJm7QH0GTIfCu0n+sZZmGMhSiYhXGFNnWyZKunC2jOqGrN7uRY1izK5VIMeyncUIVr8JJ5ZSxM\nNdtyNFShWdhy+rrREyhjNS7U1rCxcn0s5Ya6bKHFodlGoVmUIscKZjHMCmMhJXzhRJdVHY210I6s\nwL1gGeGowH1qDzELAKSUn5VS/qaU8oXAc1AJed8AfGg7BrcZbFfobI4xFkUhPt8TeM0ZVpeXyNKY\ndrqEmDlMrsMkRdJVFUG9APZdBbOX0BgoAWupnzDoq8ng7mXJchow46mb+Mhck9AXHJiJVE+FOFOs\nwZmohmluM5993ZTJTcpzBe5xxsKsGAdJVgqVVMdVREP5w0UAlv19+HlMFvfUyhcIyOjHqV3x+nqi\nSDMV+rjQDtnfiVS0EzDjxZAMEGGLoYzwZEp/OKTh5eCpVp1DQjvGxGQoa2Nx5YE2856zcqpoFieW\nevzMqZ9k/r5/U+OI1Xk5m2m3nk7KU24orxQ62yBhKNXDmHtBaRW/0I5sgqRhd43Asyv1flIwCxvC\nqY/B0xWLWy01hpVurzAWJWaR0SQh9hr8e/R0uOd9HLv/HgCe/jAVAPH+zz/Id/zfDxeX0oRE+xG5\nF+BLtVJv+drNI4d2pQzY3hNmtVzNszAZ/9UMbjCaReH6aMnh6ETpewQVN9S+dmSNRZVZRKT2PbVP\nn6elH6A5PK3CzYHMGAtH0H2wlHhZjKkfZ44bSjMLR7c5PKuuhTEeRe8PUWIW5rjakW+NZZxmI3kW\nUBhgl1lkmllcttDi4EzDTuBJKkv6DlDqhWNcnnccX1F5Ho2Afe1Qh86q7G1grMBtmMWZ7nDdarab\nxUZDZy10xdl/kFL+sJTyiVs5qHPBdoXOZtoAuMwCoNWeJZIDDqASpJg5jPTUjeolXRIieO7PwhO+\nE2aP4ndPIMhZ7CUMtbHI/SZnE5+ONha+J+yN1olUZvFSP7FVaxuBR5KkhHoSNZVcXaHatyulHJmp\nmlbqQEyHtEKzqArcxu8qpUTGPRIRkfptgjy2YbqgVoY9xw1lMsqNj3hfO2J/J7KTQ0cMIO0jwrbN\nhI8HAyKRgx+oEggECK2BxHqVbtxtVx3oMO85zMJxQw3TjH53mWu7n6D1kJpQw0x9dtEyi7LAnToT\nQ0Rsx5QLv6QP7GuHRfMj/bDv64Sc1au5QZLT0prMIMnVCl0baMMs2ppZrHT7NtR2phGWBO4GMQQt\n3iGeAjKneec/MNMIeOzlyo2WxDF3nexy35keWS5tbS7lhgrxpRKM24GuQaQ7Hpux26gtHeEzUqI8\nLworVpnFyiAtMYsmA4yC6SaCmnsAlBtqwTUWJsLHcUMZYznMctoi5odO/gIvW/k/XNP9FAkB+cLV\n+vq6bqg+V9nEy6obqsIsHIN4eE4t9Iy/v1pHC9RK37DDVuTb77vMwi0PYjULJ3w4yyUPLQ84Ot/k\n0EzBLNLcLfRZGCcTDXXj0VlCX/D5E6tKs2gEHOg0WOwnPLg0KBmLqsB9uqt7zciitPtWY9PGQgjx\nfN3q9LH6/5dv3bD2HnLtaZMVYzEzN0+HAZfodqp0DiO1CO6nfWVknvYjcOVTYPYoQmYcYIXFXkKi\njcUrnvtIBjRoe8VF/opHX8JzH36YdqQ6lZ3uDjkwozv2BR7xsKDiYaZcE5MyuEljVtGr6wnMIhyj\nWfTijCAfkvlN8qBBJIdFjgMQkpWMhUkStNmm7ZADnYY1FnOocyTCpp2Y02RA5GWWWbgd5Ux+SEjK\nk67ex0wjKMJ2hVcSuE8sD2nrfJBgqAy3yQ9Z1s2BjMDdCDzrXlgZJCqUMS+MhRSjzMLATCr79UOc\n5ap8x+P7H+IxZ/4JUBOLCZ31Q3XeO4ZZ9PuWicw0CheJCZ31wia3JZchww4rx27nKQ/bz+W6UrBh\nWO//wilVJkUzNvzQYRYZTe2GivTkbtjTY47/HU/zb3OYhTYWi/fx4/f/MJ10aaROWCkpTziRTrIw\n2q4LxhioYTBHkyELJc1CGwudcxSSsjJILZuZpYuH5BnJv/P01bfzkeZTCToL9pyCCo19cGnA1QeL\nXBqDXpyOCNwuYza9IEyZ8tiJTvI8gRBqQjc6RCv0S1WeXWZhzo81Fl6xSEsylVE+0wg4ONvgdFdF\nYCVZEaLuLuZMDkgnCrjmYIfPH19hVRsL45q6/aFlFlq6CVvoM0wzPvPAsi2Bc2qlmDu2S7fYtLEA\nvhv4CeBlQojnAI/bkhHtUeS6ErsMmqXXF+YXaIshj92nH56ZI/ih+myY9ez3AJhVcQHXtVZUr2jd\nGe+pD7+Ch116mCtnCvr4ky98OP/5BTfSjnxOrQ4ZJDkHdDmE0BfEurRGLH2idBUppe15AcXNm2aq\nNlRXGmOhBW5nxRQ70S9Q+F1PrQ5pkqhj9huEMrb6CBg3VAamL4DWUGyYXyvkwEzhhprNlGvQa3Ts\nxCzSASGFwB0T2FV9nBgjlPD/XvFUtQ1dakR2DpeYxUPLA9o6WdCP1X7M5LZEoVm48fygVqaB5yGy\noc3Ol1U3VKu4hub8HuhESL2KGyQZzzn7ep712Z/ncnGCfpIhDLPQIbPttjr/vZ5yQzVCn7lWaHs3\nmNBZP2qxGmfE+MRJync/7RoOz6r9X7Uv4vBsg/fdeZrVgcpPUQccIUVgr0dTxziG2i1oMoWfc+K1\nvFT+Ey197E1zzR/8JNcObuPK7J6Rwng2KW+QqC55AM15Gq6xcPzwoTYW/XCBNkrg7ieqrWlPi88u\ns1geFCVKOjomukHCjFzlPfMvcTpDqu8s9xWbvXoisxgVuA32dyI84TCLSsXYULtfXTdUoBuCDdNy\nBvcIs3DyLEyEWzvyOTjTIMlUb45qoU9QbmK3zPn1R2a544QyFrONgJuvXABU/m7ZDZXzzX/8QX5f\nt+E1zALKhmMrcS7GYkVKuSil/HHgBcCTtmhMexLGDWWSrAyC5izzfswzdSg/M4fsKjLK++R+sSpl\nVkV2XNtc4eTKkNzkYYQtDh+5lAU5Whiv3Qi4Xyf47O8UzCLT/uqzzBLKmCSO7XvgMIsshyxlFW3k\nxjKLbGw01KnVoYqACZrIoElIUmqLGpKq1aIObY1Qk/GSk22q3FBaszDGImyp2lCoCKqAFLxAMQvp\n26ZORrNA5rbPtwnbzWeOquqzGseXB7YMiT/UxsIyi/FuKFAr08AXiHToFP0rGwsTPWTODWBZ3unV\nmEGSM5udxZcp/zl4o3KF6GMwXRZntbHo9oc2L2O+FSKlmvB62lgEjTarw5R+KjjY9vjSaw/Ykt7X\nLIQ89doDvP8Lp5SRM8bCC8i9kICMlWFKyys0C3UPaPdJnnCQJeZaaiKdMVZFazthPhhhFkWeRcqM\nTlykfZCmLO6DyHGtGF2jH8zTEioiTkrlqjPMQmhmEYmUlUFiJ0tjLHo0uMe7gntmHj/SRvQBLW6P\nNRYTBG6DljbQVTdUGJT1hp7DLMw5GCb5WM3CGBbf0SzMmJSxUPfJqdVhqWaVGzrr5sbceGSW+870\nOb0a02kEHJxp2OhIYyyaoY+UyugZFnFyNbZdMF3DsZU4F2Px9+YPKeUruUCT8QykMMu1cg4EUYc2\nA55zuWYFncPM6ImhkfdVgTwDzSyubixzanWIMNE8jTnoHITuSaiksrSdyAdz40W+r+oOoftCULRW\ndVc4oN1QeUzPuKHGaBYj0VC+YRYxTWJE2EKETUIy5kRPnw9vxA0V6VDak/oGPtBRpQlMdE7HMos2\nsWYWXjZUk56OhkoIbJOgOHH7fujS2HJAIn3S5v6SG2p1kNokMDFYJPCEdUut0EIKbyTPAlS5jdD3\nlBE1talEUNIszENqzg0Uhvt0V0U3zaRnyYXP13jvo7d00o7X09ucaavfvcGAoe7tYfIdFvsx/Vhp\nAmGzTS5hmAtuPNxWxR21oRR5ypMfdoBTqzGfeXCJUOiJ0g+RXqA1gMS6oUxkkq0XJWP2y7PcfMU+\nfu9bbubJ1xxQ39fnMcoHI818Cs0ioe0lyv3XnKeRj2EWvmd1jW4wr/KGnEJ83WFKK/QRUk+O2g1l\nVvjtXBmtH0t/mB9q/CLNKChao+oJ1URCXa1L+S+7AndSCNydaJRZNAJloM13qpWETW0rYwDMPWJW\n8tV+FqCMYKkIpxDWNdaKAjsO0zul6iY2DaTMWL/s+oP288aYP16zC3O/NJxjMvs6vTrkxqMqau7k\nyh4zFlLKN1f+/91zH87ehY1wqrihiNpqslw6BtEsRG1mO2pibslBWeOYUaULLvOXObk6xNMrOhoz\n0DmkCrDF3dLmzQoJlJ8c1EooEsZYqBsk6y3zdO9WnnT3q4FKBnemomwQ/lhmkaRFsxgooqGUGyrG\ni1pWqN0vlFGSzQUnz0LH2xOzGqe2pILpyjfTUGNpJ2cB8KJW4YbKYlsbKvDKxsJtjmOMXEv2WKVF\nEnRKbqjVYUrH+NT7iyoMU+cFDGSkjLbjhmqV3FAC0iGeTqDDC+wxQfGQQuHeO6CvxcmVIeQJrXSZ\nYecyPCEZrp61obO2f7vOsxj0VZ2sVuRbI3S2lzAcDvGFJGzq/u74XD6vjZQ0eRYJl+rV4xdPdgs3\nlBeCFxKiJsumb9yCZWYRyIR98iyegBc/5lI74ZnzGMnhSDMfc5/kEjqeEuCJOkQTNAtzzrveHC2G\ntEMPQU5/oMpsdxq+XVzMhCpqzkyWbc1W7skOciye0Z0li9BVKHIsrtjfwhNlZtHTzKId+fbY3Im1\nGXrMNQtmYY7VRjL5SuS3moU1FqoYYZHE59nJvp9k9m+zDSM+dyoCeZzmlsWETu02Ywgj3+Oxly9Y\nbcUY2sdfpaLh3AAXg2Wt+ZxaHfKwgx1CX2xb+OxUxsLUhpri54KtDWUinERYNRY64evsF2FG9f2e\nn1EPfIthUUgOVDG59kGOeGd5aGlAlHfJ8dWKtqN7hndPljY/GyT8Wfir3CTu5oBezTZ8z5bAOIMy\nFml/ia/wPsQj7/1LwK06K/HyhEyEaj96xbsms9Ax96dXY5pCuUbMRHrQRH01FwiEYhbCGouE3jDl\n+PJQ17BRD5t2udNMFtVpiApmYd1QfoDvebrAoBG4nSQ0vdJv5j26NIn9TolZqGRBPYENFlWIqGYW\nPRoq6CBLbOisq1kYZuFFaiJWbqhyNJQ9N37ZDXX7gyvs08J9Oqt8kf1+15a9MKGzQrsj+8OBErOD\nwlgs9mJbGiaI1L3j+yFt40HRbhuyxN4DXzzdU+dNnVCkHxCIVGXE6++FuWMspOqv0ZTD0S6DeoES\n5YOim1slgxugLVKVkR51Su7IkrGgMBaByOmEkt8Nf5crfu9yesNU1VrS98tsIFnuJ3bSbmlmsSJb\nLPZiWmERumrcUA8u9fE9weHZJo3ALwncgySz1WKrYwOs688k6cWZLLECU3nXGIt2WERUDdPMlgKp\nZnCXqh94heFoRY6xS/JS+XvfPp85cZapXA8ttL/gJuWBMMbiSx92AN8Tlk25rrWVQUJXNxc7ONvg\nQKexbQL3RmpDSUyz6PG4oGtDGWZhJhSLUEfanPmidTMtaGPhCVk2FgCzl3AgPaNq4gQDkqBDQwjH\nWJyC/dfYjx/JT/EM/1Y+Ja/lwMz3A+oBKNxQmlkMVohEip+VaxilmUTkiVpZB1Gp6iyo2PtEx7gb\nuJpFx0vwwhZCT2KGWYj2PqLTS/TjFCELN1R3mNpMaoMZPdc2YsUsCFqkJmIsG+IHo8xiqZeQuG4o\nPfk28i4nZIvAa5fyLLpxynygV1SDJRpBoVn0aZB7Ib5mFo3At6vGlUHCgbYPeUJgrq0fQlZMhvMt\nNxpKh862I46KMzz21r/mA0JFjsu5y+FBGPZ7NqLLuLZMifLBYKjLtXs2ymqpn5Dq6Lagoc5zsxEV\nukleGItDOlfgntNdDltjESC9yDKLhqezinXocJLnlOpKrZ6AxmzxvzYWDYdZVKOhAFous8jHMAvf\ns2XMlz21bpz1Yr7M/5C+RpmayAdafwoky4OimGAj08aCFrmEVuTZlbkZ14OLA47ONfE9QRR4lWio\njNVhZidZqDILZSyMK8uNTgJHs9BuqGZUuOLcaKhqBnd1GwbtKLDnJs5Uf/ei90cRqjtM8tI4v/yR\nR/nzD97DrHZDXX9klo/+9POsduaGA68MUhsRdXCmwcHZqGgStsWYylhIKZ897nUhRENKuX355ZuA\nEOIlwEuuu+66Ld2uzZ0Yo1kAsHQfHH00AAszHfu2VxHEmT3K3ElVgnpW9MlC/dmO8lVWmYVJ1Hus\nf7etgBk6zOKsZhb5YJWIBF+mkKWlZi7KWOh+EZNqQwWjVWdPr8a0vRTCFoEuH75f6PDX1j4icUZp\nFnrl6wlJv9/n+PLAxrQDmIV5NNTGImyR6lLvfj7EJy00CxnQ7/d50f98F0+aG3VDRWmPLi2aflut\nkPMcPI/VYcqCH+v6xzkLwZCWdokMCZWxT4cjAvfqMOUKHYUWNlrmolUE7lFm4XuCFzU/zYt6b+F2\nbfi8hSvU/gb9IpvduCF1ifLhcGDzHUyUlTzxWTJd5+nogQVuvnKBTtooxmCYRZ5YreSLp7o81XVD\n+aFN0mxogdtoFlkukemgWOmtHocD1xbn1mgWclSzMBNjmktaIlHMImwTuYEOjk5m3FArQt2XMxSf\nM/WO6Gk3TZApgVsbgqZmFqtogxmUQ1dBCdymo14j8FhyJD4jcJvif+5xgHZDtQLbfCxxSrGr8asE\nvn5sBOpC9ximua1q4CbxDdLJzMJ1hxlmYQyZ6yauMvunXnuAX//6x/CCRxZVldwgC5dZLDsi94GZ\nqJQEuNU4F4EbVPkPAIQQTzvHbW0Jtispz6wMvUluqDy1msTC7Ix92w+rzOIonVgZhA59ct1tb5Ib\nakbnXjxKfNGK31Hg0dCahXmwsqRvJwvSfmnl4suU3IvAj0pVZ6HIs2iMiYY6uTqkraOhfL3qPsCy\nymIPmkQio5cUbiiA/qDP8eUhR2YLI9kxsQHDM/qPti3I6OexMnBOnoXIE053Y06tuP2z1fGG2Sqr\nssXACPY6lLc7TJkPCuOy3+vRYsiABhKPXAQqOTHLeeTiu9j34HsB5Ytv69pTUVNtU/gVYzEmzwLg\naKQe0if6n1fv7b8SgLjfs640Kv0shsOhbvSjVrk3ibv5mvd/HdesfETta26WN/3HpxEGLrMoCgmG\nvsdCOyxHQ/kheIH9v+GZ6KeiJtHbb7mvOJerTjFGsMaiWWIWxXHa/h4YZjFjjcUzvU/RfkAxh8D3\naBAj/QZdtMa1eKvdTneYqs5z2vh1/KykWTSyVVK/Ta6npVYldBWUZnGJ1m2qlZKNwG1EZTX2YmJt\nBioayhW4q/lFSrMoyn2YbQzTovdJmVnkZc3Cc5iYmwGuM7XNeFw3cZVZeJ7gG554RYkhuTDMohl6\ndOOME7pHx6GZBlcf6FhGstU4V2PxdiHEy4UQ3wq8aCsGtFdh3FBBo8osnHLiM4cBODhfMAu/alxm\njxINTuGRq1VXQxuW9nhm0dHGYj9LsKwYSRR4NLQbKgnU97N4YNkGSb+0cvGtG6pgFqEv8ETRkau6\nOspy1SC+SQxh07poLhWnydsHwQ+JRMYwyW2SFUCv1+Xk6rDkhjIZxZ7pzRw2R42FzuCOCazRW3JD\nAE2SW9JllSZdoa+DFme7w5R5v1hR7fcGtBgSe2ocmRfasidPOfYnLHz894rxafbW0OKy8MNKUl5o\nz4vxbwMcDpTO8HhP9b+IjLEY9u1EXe2U1x8YZqcmwhsjVahx30CXgjfM1fML95NlFmpMRrdoB9qI\neIFiZtZY6EnNZLD3En7rnz5dnMvVE5TguKHMhOhOXibTuylirVm0dXa85L8Eb6D1od9SQ/eVZpEH\nTbq5Ou75E0UloOFwqJLl9HG0/Zxlh1lEaZc0KhZazUroaq6bCl3qMAsD00N9dZCOdUNFWg+Yb4W6\nc15G7JTfAHT/D0kvURVmXZE8TnNVsyr0EULY52uYZFashvJiouO4oRSzyOxE77qJq8xiPZgCkI+6\nVC2Iv6jrlh2Yifi5r3okf/V9T5l6WxvBuWRwvwb4KuCbgUdJKX9my0a1F6FXhr5rHKBwQ4E1Fu1m\nMVEG4agbSsicAywxIwZ4TR0TEDZVCG33VOnjbSdrlgc/qT7qF5pFFqqHK0+HBbNIeqWkH18mavxB\nw066QoiSQDjSKS9T8eaRVKtJ46K5XJxEzhwGX/nIh2nhhgJ46MwiWS5tRAfAvlZlpRO2bfXehkjw\nZTmD2xyHXTmDZRZ+skpXtopQ4Nd/K9zxdpXE5GTAL3hd2mJIYoyFKIyFLzP8fnGem9rH32ypaym8\ncuhsQxcJdFeQAAd0P5IZuuCFeLPq+qdxv2AWpkOe7sGd6Qivp97zB/Cpv+bySBm72UQVbCw0Dn+M\nZqG2aXpVd3ypjJAQZTeUKBuLzz20Qq/v9FYZYRZqsmkymmcBRWRUUyqWSdjGI6NBQkRqFwGBp0Jn\npd+kq+tsdR74QLGbOC4J3C1PMQsbwpqukoeFllLKc0hzzuieDcYNFQXF++0oUNFQEwRuM0mb8vWq\nx8W4MjeSge6SZ2D233Ned/MsquzEjt8VuNNMC9yVPKhcGxGHAa2Hm69c4Eeeez1f/ThVN+uLuuCk\nidDbLpxL6Oz3oPpc/AxwXAjxR1s2qr0IvTIMGxWmEDrGoqMmCztBjPu8Tsy7xDvLDH38piM0mlwL\nB7alKcADnwTUzWtYhNRuLJkMrWuKpF8qjKY0gahkLEDRWBN6OPahSTIVfhk2bUhnS8SImcM6VFOJ\nky6zeOi0yqVwNYvL5pxcE4CgaZMVGyR4MrUZ3Am+nfRshzhQE6WUiMEii3T4xBnt3jn2MfjCO1V5\nBafI4ILo0mRIqgs/piK0PcN9meI557mlz9u+OXUuo6hRCp0FlcUdeF7p/C14zgTcOaRcNEA67OHl\nMQMiNZGDOv9gj+3ah/4Rbn0jlwZKA5pLtbGwzCIY1Sy0ATPGohXk9l4TfljUCrPMQkeDxaldXACT\n3VAMRzQLKCbaBrEK6NALpBZDIlKV0IiaKJsiJvcbdHP9vJy5o9jNUBcA1MfT9HJWh0Xl2TBdLdyy\nuMxCha6a1qL79fFb1hB4tvOjqalkx25caHpbJvx0SRuLcSHjppdFsQ2fYaJCak1gRKEJytIioqpZ\nuKGzbjSUW4uqWshzPTRDn//8/Bs4NKvu7S+e6jLXDDbETjaDDW1dCBEKIX5ICPFGIcQbUSU/Piyl\n/C0p5fdvzxD3BqRv3FCd8hslZqE0C5xEvDAadUMBXNtcpSP6hC0n2rhzaIyxUBNc35+F47epXTrM\nwkS15MlwrBsqyXICmSrXihM6C5SYRWl15JsQwpSwwiwA/NmjanIXqleyKDELZSxcN5SJlipOSovM\nMAtjLHQGd0qgayDJokMcqGio3hlEOuA4+3nNscv5D8OfJW4dgliVR5gRA3vuF0SXNkOyQOctiMAa\nC48M0T9jGYUxFpccWODdP/EsDsy1S6GzoLLRH+PdBb9yGSwpl9EcTghq56BtdJTFfbw8VnWuDPS4\n9jWFPicZLD/AEU+dr4Vc6zmWWQSjzMK4oXTYbsvPi3vNC20orXFDeZpZrA4zGjjXYIIbqkU80v3O\n/buBWjiYTPcQXczScW02SciCFvdxlEVvH/llT+RfMtXtLkkGamWu80aaXqrdnepcB8lqKUqrFRXG\nYJhmo3WfnJIkilmo2lAzYwRuE9AxaixGF0n9pDAKUITOjmMW6rjLz445F6HvlQR6U/UXygL30LQc\n3iBMJv4XT3U5OLu9rAI2zixeA/wO8HX653eA/7PVg9qLMHHy0Yhm4RoLLVI7zMIfcUMpZnFNY5lZ\n+oUbCrSxKLuhmjp3YLV9BXTVQx76HpHO3hX6+7LkhnIE7lzqPAbNLLLpmEWa5+S6vSlhk0azOE4x\ne0QZC13l1DUWD5xaBCi5oUqrdO1flxOYRSx1xBdZxVgksHwMgDP+YZYHGR+TN5IEszBcUeIpQ5hT\n53dOdGmJGGlW+7huKHXMl4V6ktQCN0GDqw50RjQLUBFRV4vjyoho7Wgmd43FITvRZ8kAP49JcBiV\nvide+AiVNR2IHJaPcVAoY7EvLyLF7HmqahYVZtH2CmbhBaFN0ouEaywk3aHDLLxglFlo3afFwOkp\nPcoszMLBsKSGSNV9mGg3lM7gzv0Gx+UCP37V/8P7vn/lXfJmPf6U2YazXc2ETPl3P1kF53loVtxQ\npkLtTKOcnNbQ0W2rQ1WivcwsTB0s9XtOG4vlQVLq/wJFYEe/wiwi3RKglxSv+yVj4bATzSRdFxo4\nzMKcS1fg3iCzMDAutdPdmIPb7IKCjRuLlwB/C1wH3AC8GaVbXPAwZTvC1hqaxRg31EieRecwILgi\nXFIlu43ADdA+MJqU56uHXOy7yr7n5ln4mpnk6bCYEJJ+0VwlzZSrIIiU2DrCLLSxqDw0Vq8ACFo0\n3ePuHLIr2aobysuGCFFMaHpwxd86LyX3zIQTq+9bzUI9ZCHpqBtKT9JL4SH7chzMwHCV7jBT5T5m\njoDwmZNdWgyRen+JjoYClHECLgmVC8iW3nZX9dkos7BuLr2SnpUrdE3Nrc6horZUMsDPExK3iKQQ\n4AVcvRBy68+9QOkKg0UOp6pvw4JO7BuvWZhoKDVOwyyavuuGKgo2htpYCJkTkmljobc1fzmsjNcs\nWiK2hfFc8djcG1GumYXjUgtJ7T0VajdU5jdtiDIUz0AoUpwoZBp6wXNKBzL48QqiURgLO+GG2lgM\n1TWZsXWfCubRinxrdGbGaBZj3VCVSdqEjPeTimah99+PU8s4AkfUHhc6awyWECofpB+npLks3FBW\n4DZGZOP949yop4Oz0Rqf3Bps1Fi8D9WL+y4p5Z3A+1ENkC54PHD0ufyP5KU05o6U3/AjNbk05q0b\nwnVDUSlpjh/AzGGeMHNGNRFyk6M6h6B3Cm59IwzUirMph0jhcfDSayzriBzNImjrh6sicJubNte9\nIbwg0slmTk+C0LNhhFVmEad5MYmGTaKmG/WlmQUpwyTDIyMWOsO7pYQ29wEqGQs9Gfq+T0xAx2Rd\n+wFCCJVpjpqIghFjodw/q9Fh+/LQayGHK3TjVHXwi2agOc+MXFXGImjRCDxS6bihtHG7xFcJhk3L\nLJzrV9Esvv7xl/PMazr2XAM0kmU6V+lWLp2DxfeTAX4+JHWNhd1uwmyzYC6HB3eXPzPODWWNsYQ8\ns4a4ITJ7rwk/stffaBagdIVunNryMBx+JKw+BCsP6U1Kq1m0GVo3VIlZ6AkulMMSsyiMhe7JrjO4\nM69RWi17hpWTMhM6K3JtLMwk7yUreK1xzMJnkGR2YWMmyYYjcLdC39ZEGq9ZlN1Qy/1U51mUE+oS\nHdjRrGgWJhrK5F74rk5RaRwGlN1YvmddaKMC98Y1CwPDLGD7xW3YuLGYB35VCPFuIcR7gF8BZoUQ\nbxFCvHmd757XeNaTn8BVX/MzVlyzEEKxi5litesyi9LfBrNHuTLXoZJOqCCdQ8qf+zffAx/+Y/Va\n0kOEHTUZxavaxVQwi2azQyx9xSxMYbl0gOep0NhEV6f1/FAbCyfKJyyYRTjmhrc9l4MWrXZFm/GL\nZjuezIm1kPz9T72MH3luJSHSnXi1myX0PWIiW0XWTHqm1/mV8wGecIxFqpmFFzBoHLAvD7wOcriC\nlKiy2VEHWgvaWMTIsK2aRRFYQ2mYxRFPGwvDyEwCpR+MaBbPfvhhnnalKfM+UKv9wRJcdjM05+Hg\nDar6K0oE9/OEmMpqzw8hK+sQHmWjRLiGZgGQJbagZMPLbZSV64YKnW02iOkOs4J13vAC9fuud+lj\nGRaCM0ObvTxO4A4mMQvtrjR5FqlmFmYy93SuUUBGxzUW2ridWh3ikePFq/itIj/KMItOI6A7TEe7\n4DnMoh35tjT4uGgoM/kbQzNWs9AFNPtjo6GUZtEao1lEJcOh/q4yk+WKu9ct9OmG1G4EMy6zqM5L\n24CNZm+YxLsvc157hv69Pb38NojtyuA+NNvgpU+6cvybYacQt6HCLMbQw9lLi4fVod088muhfxY+\n9Vdwv0rSMj2rizyMUzSCOUvh260WMSF5MnDcULrOkO/ZkEkvbOiVbbHKn20UPaCrzAIoMYvQLXOi\nQ2c9JEms3EiJ1wIWufnSFjffdHX5eEtuKLUd00J1RhhmYYyF+v2Iw00eWBnjhpq9hFajASjXyUC0\nkH3lwmnkPWUsmvN0VlZpiSHdoEUj9InxrbEwGsthLS43zap7DTcUALGOfkqHMFwCpNKgfvRWZfSF\nIPUiRNbHl/Eos3CZXT5m+2AjqsZqFvp7JWah7y/hh3hC4pFbN5Q6tliFFRvWedkTlLvzC++Ex35T\nqU5UW4xnFpHv4ZErrcfVLEg0s0hAqmKUbYakXquUO+CHEQyUcehEo8bi9GpsGWbQdoxFVLiO7j3d\nHVN+vNAsms7kvN9Jomw4Irg5rijw6MXZiGYReB5pnpUYhPlukintpz1Gs3BdUuZ1U1fKfN/Uoyqi\noQo3VDUpdlqEvqf7vmfWNbmd2OgIr1nj52FbO7TNYdsyuNfC7NFSPSc8T1V4Bar9L+znTYKaq1nM\nHoFn/xRc/QxlLKRU4mHULjK8e6esZhHLgFYUEBOQVaKhQPmQ+wNT/TRSq1BnErzuSLHvqmYBri+/\nVUykoIyFLn+SpzE+GYmv3VRuv2+DscxCMJRBUfzPMAv9+8aDjYrAHSuBe+5S2k60S1e07YQXZoZZ\n7KOdLauw46hNM/RKTZWENl4HUcaiUWUWXqgm6Eq5eGOESfrQX1R/NxcUs/B8Pf4IkSlmMckNpU+c\nfdn09gDhjGFMngXY+lDtyFdJebayQCVCSaNJUha4gxZc80y1WHFcUHEwS4t4pJkPKAbqLhyMYW+I\nRF8jCVlM4Hl0xIAkaDNMssJY2OipjIPt4toFmuGd6cbM6l4WXnOuyOvQE/NCK2Sxn7AyVMly1fLp\nUeDZMudf8eijPOVh++0+qtFQoJo+DXTJ8HGaxYgbSn/3bC+xjMFNxAvHLLRcN1QUFMyiWhvKCNyb\nYRZQMKWdYBYbGqGU8h4p5T3AKeB+87/z+sWJb3kDfPmvll8zjGKcG2ru0uJv1w1lcMWToHcaztyl\nxMew7dSOOmVrQ8WENEJPMwvXWKgHz/cEw6GajL2gUZ6sgEccLVhNVKkNBY57JmyCzq4eCFVIzhxf\nmsZ4ZDafwYi/JYwRuH1PMJAus9DGR0+w1x9sjArcS9pYOK6ALk28eAWQBFlPbX/2UuaSk7SIEWFb\n+ZxlgNDF/UwJ9P1yEXCNhcMsquOGonx8OlAMEKC1r/SRzG8SyURrFhPcUFKWtn2XPFrs3+RljNUs\ngCyhHQX82395FpfOBYUbyne0HufzLYb04qzIwQkiuPbZSrc4+Vl7TMPGfpoM6SdZqRIrVEK1g8IN\nZQ096HBtwQx9Yr9t29eqw1afP9CCGw8V2pcxFqdWh8wIs3iaK5WzAGyl2OW+6h5nx+Wwhu946tX8\n6POu57e/6eaShlA1PObvop1wWbNIM5VfVHVDgSpmaBiMq1mEXnkbQKk+VcMpeGiOTQiho6/yTWsW\nUOgWB/cKsxBCeEKIbxFC/L0Q4gTwOeAhIcRnhBC/LoTYWp/P+YaZQ6WQP8DJ3B3HLC4p/nYFboPL\nn6R+3/9RtYoNWyVjYZmFCIh8j1gGI6GzoGjqUJeXCMJG2WcOPOISx1g4VWc9YywczQIg9xsk7XJ4\ncJYmeDIn9U1zpTF1JccI3KHvMSQc1Sz07ydc3uHp1y4U30uHyg01dxmzjZD5Vsih2QYrsoWQGW2G\nKmM5moGFK5lNTqmqv42OKtcgfUSWIMht850FbSwiy6AczaI6biiYRTqEgfourYXSR6TfoCESwqzP\nwKuEWRs3lMxLL191w2PVH25pmJJm4XxeG7qj8028LLETtx/oPCAyFZar0US5oVq2UVIDLtH7O32n\nYywOqPItw+FIclcj9Ip7yw9tvauOmzCaqiZWTZEQey0Sp1VvGKnPP/HymdICQOQxTR1ptN/Xhqcx\nSyv08UQx0S+0Q3KpuiG6fnrj0ol8j0ddNs+PPu+GcmAFRTRStfqsYRZVzUIl5aXl0Fm3TLt2L03K\ns7DMouSG8mzfbzdT2xRoVJrFxqOhYG8yi3cC1wI/BRyVUl4upTwEPB34IPBrQohv26Yxnp8wq9Ox\nmsU6xuLQw9Wkd/9HtGbRLtWOijSzSAi1Pz5EpP1ikrBx74KBLn0dRjpqy4mGuvb+v+V7wrer98cy\nC8f1ADSbbWb3X1o6Pi9PCMjIgnKkUAlraBZFNJSa7HItcHd8yfd8qaMRdU8q193cZfzAs67lD7/t\n8XQaAStSR2HpfAWiNuy7yn7Ni1pqcpC+HmsxWc3ni8AazKKqW1jNYlB2QzmQfkOVwci6xTmxg9HM\nrmKE2pc8XO/fMS6TNAt3TFls7y8jIodkpWNsilj52nUCIkGjCPFePWHLvMdNdX/lca9YbffPQpba\n+w1Q+zPMQjjMIu0TZbotqlDsoXBDqfN68+UzpWMRWcwTdGOfBWMsmvOqu6KuwQRFbsT9Z3tjw2LX\ny1y+4cgM1x92a055DJJ8pOqs73n040yXRy9HQxm0ozGaxZhCgu0RN5TRLMoht5vJ4HYxq5nFTmgW\n0wrcz5NSjihyUsozwN8AfyNE1UF7kcMYiWqeBdjEMWC8sfB8Ve78+G3KWMwcVZ/zG0qz8D0ioXzi\njUC5oQJdfRUojIXn2WgoP2xAHpXcUMFtb+Tbont5TfLlYzWLBmVmQdCy9a+KiJgMX+QMA6NZjHFD\nuStpbSwCz2NIxIzQmct6gra9zrO4PEme+aI+d5dy9cEOVx/s0Il8lnI1ER1Gu4WiDiwURsZrzNCO\nfAYrPp5MSv78+fQUjxZ30ZBD1S7UsEEzhhFmYdxQw4luKIImDRI69Jmdr7xnmF1puwL2a7mvxCwm\naxYW6RB0lJofFBFHfkmziFV5cT9TIShBo8gNWj1htbC4ofz8ctglClpKe/qdm+E5P0MjfJrTwrUw\nFh2n/DjpkFCPzeSe2NDWhlr1PvpIq3IsMU+99iDvu/O0yt6OgGiGZtgtTdamlPuxs30edVmhRTYq\n2sUkvO2Hv6z0fzP0GaTZyCQdeE5L1HDUDQWFEfHF2syiXTE2puZWIyg/Z4NEGaf1jmES5lpqDphU\noXYrMdUIxxkKAyGUY3atz1yUsG6odZjFOM0CVHRV75RazUZt5cvuHCy5oRJrLALCbIyx8AWxNhZh\npN1QeVoIt1nKfqHF4TE3vHVDmUns+T8PT/2R0vGFIsUnV2XLYYLAnRbnwRoLla3drjAL27M8T8oT\ny9K9+twVNf7bUcBSpiaiI2JRb78DCwWz8KM2M42AXurj56nt2kdrP+1shbc2foabzv5rRS/wi3G7\ncJnFBDcUQYMGMTMMOHTgQPk944Yy233MN8ELX1UYnGCCG6oSDWXhMAvfSXzznfIqhh3aLHVf3wet\n/aoigHZDJZpZyKSn7oWl+5RBPHsPjcB3WrgG9lqV3FBJnyBV21rJTaE/dU995c3KeHeCvDgmHXH2\ntOvUfjui7IZyV/MmN6IbZ6VEtGmZRRXNwLihqu2EhRWi3b7r7kRujIAJTQdGtgFVZuKGIRevh76w\nEV6bret08xULPO26gyWNabuw7giFEM8XQvyxEOJx+v+XVz7y885n90RPiz2BtdxQrX3qoRV+Ud6h\nCm0YlGbRdl47aZPyUhGpImeEKmzUwITOeoJYC9yNRnN0xZwnzGQqBNSNTfeNKFhlFo/6OiW+g50w\nAjJ8MuXn9xtFlJeLPC0YlN5W4FdCZ21ymfa9Vn37JonMuONQIuLZTDML4TCL2UtsSfnO7ByzzYBu\n5uGRMRfqbT75Fbzt+l8EYP/w/nLUmj+JWbhuqLO6Amv5+nlhkxnRpyESDhw4SOXNshG87PHwlFeo\naCqYbCzWYhbGDWWMBam6HpQNfstT9bcwUTwzRxSz0NFQSatwQzUCT7UJBohXS4UrFbPQ5UZKbqgB\nYarOjzEWJhz0ioML+jjS4poGLchiHq2ZgnVHRh0aoV9mFk4o7LhSHhup2ArQjPzCDTWhcdHh2eJa\nuBO8yzhM+Ou4qrNuT41Szkql2VI3Hs2Y3wi+++nX8Cff+aRNfXejmGaE3w38BPBtQojnAI+rvH/R\n9LTYEGw01BhjIYRyRTVmitVsFe2DakKKV4oJqa0MiO8JGkL11W6GSuA2/YsBp7CbZyNj9s91CuHW\nTDhZjC8T/uJlj7Id2GCyZlGCKX+ifeTCC3S5ktOjn83TIp/EYRbDMbWTvvfZNxZjdCdrUwalXYRF\ntqOAs6mauA4bZhG1wfMQumtdpzPLTCOkm6hjWgj1NjsHuOfSr+C4XNAHXZmozRhclIzF4oheAUoj\nOaBLd5QqCptjdN1QhsE0y+fGjmFsnoVzTrKhI8o7xltmlrFaZiGycrDFzCF1TjWzyFoH9KGtKj/4\n2bvV54bKWARjNIsOZWNhmYXWkWw4qD2fcXFMoTIWvu4xYV1aUYd97dC6nqBgFjC+lMfGmYUKnU1z\nOSJwGxxyCvONc0NBYRiCMcZiIrMIyvvrxYZZbE7g3klM4+hakVIuAj8uhHgVYM2Y7mmxBNwMfFBK\n+VPbMsrzEWZ1Oi7PAlRiXpaOfw909JNUWcKWWRyCU6orW0ukZCLkQKfBGUKaeb/okG6T8oT1Nbeb\nLYdZGGOh3nv6pWWDZW94G245hv347ko2VxPf7BEVkllFno1MiIGvNAsLPaE86gq9GncnFgPhlSbo\nTsPngURt4xLPCNxqkhQLV6nQ47DNbDNgNfPAgwXTTc8LaYY+98gjyoXlXqdJmoWblJf0C0bgIGy0\nbZ/yERejH6rvua4YmMAsxtSGMufFIC3cUGbMLU+qPJLGLMQrtPU1bHopuKG8ncNw7KOKWQiPtKmM\ncD7sKVfPWR0JP1whCirRUMYN5TKLZICvM7kXM13ew0yiZoyuDhW2LKt5/yufg/+v74GPKRfZf3/J\nI23eBJRdQuVoqE0aC6dyQVRZ6Ru4xqIUDeUwBrOoisaUKK9qFvbvkhvKozs8N2axk5hmhH9v/pBS\nvhL4M+f/i6unxUZgNYsJuv+lN8OhGyd/v+34u103VE/Vh2qIlMyLODzX0DWWHPdPYmr1uA95VIzF\nlpzQE2evzAbMDT/ja9eFP2ZN4ZvqsMrt4fmBEuKrRepAG4v50rEEnnCS0RjVeLKkmFjMpNraX7hR\nUOGJp7WxOOovlc+VEbm1sYg1i7GtV72AVuhzr9SZ9+5EvW7o7EBNdGOCE8JGi45pWFV936toFlVj\nUWUWcgyzKEVDjTKLTpCV3H62C6BIK8ziMKxqZhHNYPqyNBmq1bthFvEqzdAvAgMmMos+vmYWZ9Oy\nZlG6pi6zSItaTk1ZdI28bKHF1QeLSLJm6Nttjc+z2KixKKKTxukNgSdKzGacZgEFExnHLKrRUOO2\npQp2nptmsZNYl1lIKd8MIIT4ReD/SCl/t/J+H1Vg8H3bMsINYrvKfWwYXmXyq+LLf3myCwqKvAoo\nWre2D6gJK+7RIKHvRTRDH+lH+LbaiihlcEfuitAmmxlmoX/3z5R2bf2uXjqeVTjHZUM1vVBNQMc+\nOvrZPFUutBf/JtygPJWBL1RWtYFXMa4ll0UbhstlA4piFifiCBpwHUYA18EDJnw2bDHbDGxviTnT\netUPaUUed+WHwafCLCpuqLf/NDzsWU5S3lBPspXQWCrbaYxhFllabNccczSLyt6eQrNwBe40LgyA\nHnMrUMUGzaTe0ZWDGyItR+Z1DqnorrN3Q3MBoe+xFkOajQBO360+N1zhhY86ypHjl8NHKBmLViXP\nwk8UU1DMwun+5ro/zTEFTWUE80yxqOHq+POpsdAKObEyHNsydePGwi/K3IzRLA7NNmyukdq+o1mU\n3FCjmoUxIK1odJwwWlZnpZLZvZexkRH+J+CfhRBvF0J8gxBi+2O1NoFdKfcxDmsl5cHahgJKQq5d\nLZuomcEikUhtmKnnTlDNuVI0lH2go055IoZi0uqVjYWh4x0/Ga9XgJ3oAqFKiQvPV5FK3VOj7rVc\nM5QnfrcNGzahsxZmQim5LIwYqsdQMRbtKKArG+QIDsqz6n1T0PG658PDnq2S+Johie6TMe+biVrF\n8t8zjllU3VAfey3c+v+KFX46KFbkVbjbicZoFq7AbTQLz1OaTjUpT+bKBVViFq5mERcGwEzgXq72\n4fmqAKQWuBskFWahj/uud8Gljy2MhRiq1bvVLFaYa4Y80yRI+iH4AVJ4FTdUH6GN6SnN9kaZhXNN\nDYsy92C8OjkykEK3mHEqrW6eWfg2IDAMRlnBoUojoYnMQn/eZSem10apPlU4nlmEvkf3PGIWGxnh\ncSnljcCrUD0s7tTZ22v4Ui5irOeGWg8uszAPljEW/bO0hSplAeC73fiaC6UMbvtAR51iEjQP6AQ3\nlKXSIlmDWRTlJUJh3FBHAGmbNFnkWbFa1xgRuKtMzF2FWoG/ELfBlFQQdLWgyqFHFG9e8hj49r+D\nsMlMo2AWM6ZPt9YsCjfUGGZhV/ZpkecBmllMWAmXmMWUbiiAZ/wXePQ3Op/Vk5JZfRvYQoTaKPhl\nN1TLhKf6IYQtWyRRMYuKGwoUU73sibbvR4uYg0FPMTkoCg3anuLq+kgvLJf70K65VHosDitagrmm\necUN5W53kvHVMLrFTGNUC9iMwG0wLhrqUCUb2p3s3Wgo3xqL4v0nXb2PN3z/l/Koy8ZXR4gqLKRr\nS5fvfYF7I2dZAkgp3ymlfBnwGKAHfFoIcdN2DO68hpn8Jgnc66HlTIxVZtE/yyF/lZuuVcULo5Kx\nmC/VhrLMImyPhoROZBaaSnvxZGZhislpN5fwgyIHYqUicudpMfmZffjeBM1ighsKRoyFERtX0BPP\n4YePHarSLHRmuOe4oUKfe6SeNNfSLPK0WGmDMsaT3Cbudia5ocYZi6f9J3jYM4v/XYM1Ls/CTLKG\nWejPt728YHJh0wYpRBSlQdSJOFT8ffkT8Rw31CW5vn77rrFd9Oy94kT5zVSNxXCVHk16SSUBzXXr\nyco1LTGLyW4oyywao1rCRidaV2QuJ6Oqv0eZxXg3lNUsHJeVEIIvuWZ/Ke/B9jAPyjW3Qs8jyRTF\nudCYBWDrRH0V8OfAS4H/Bnxx7W9dhFgrKW+q7weFcagai+UH8ZIezQU10UWNqrEoMrjd+PViIq5U\nPq0yC+N3JSlPfi48Yyx0jwjPVwI3jLbtNJOXg/WZhRs5M94N1dEPbldqY3FosrEwHfg6JtHQC2hF\nPmeZJQlm1tYs8qzMloxmUTUGUN5OdaXsBeVyH94anlzXWJSioYyh14uAKrPw84LJRbMcRi0Eouq1\nNMxCeHDJ4/D0Sr8lhhzM9LEeeaTSNfLMYRZqXNILy3kWiWIWPdEada0I4bAqU3ZEj6XELNYyFuq+\ncKOhDs81iAKPK/ZPYL8T0KxEJBmYyf/wBDeU74mxlQ6q9aiqmKStuCV2LjTNYkaHzt4FfBPw21LK\nh0spX6VF7houztVYQKFbRBVjcfpO/b6aPBtN52FpLaiJJM9UfwExIA+aamU/EjqrH9T+BGYh4slJ\ng8ZHridfzw9U6CyMMguZjWEWwkYoqe1VNQvHZWFcYVXNQoudq6xnLELrhuqY1qhewL52BAgeetjX\nKX3DwNUscl2C2yCaURNo2l9fs6i6ofyoPGFOayzGMQuTKW+jodR5a/q5OndeADe+kJvzT3O5OElI\nMipwg+qc15jB9z1WZZMZBsyh2YTJhI9XR9xQBI2RaCiGK/Ro0dPhoKV6R35UcS1WjcX46DKDglk4\nxmK2ya0/9wKecNX+SV8bC7dceTgm7LXKLMxxtJ16Ve7n1zMWVlupFAu8+YqiHMyFZizOAA8Cj5dS\nfouU8t+2aUwXBtaLhpoGRreoMouKsWi2nAndhGGmAwLfoy2GCLNiq4bOZuM1izAf8Kfhq7g8uXsy\ns9CTu0n6En7oFKg7B2bh+Wq1W43Jd47XwDCLVatZrMUstJuGwlhcsb/N3//I07nsm34HnvQ9zljc\nVX1FrG/vh56TLV6FOV9B0ffBYlJS3jjYMUzQLCyzKLuhbjzUKs73E74TieCb/X8llBWB2w+VMbj6\n6Wq4nmCFNrP0mJE66suU0h+uFmN2MsZt0yiwOk5fqMZHUPb1214qsrIAMMezXjSU1izcch+wOV9/\n0/nONAK3pxmF64JSn1ffdZP5xsFt/+riG594xchn9jKmjmiSUj5qOwdyweFcBW4oJkczWRqR2hoL\nZUzaLac/tklaS/rMNHwORWlhLNzQWSmLB7eiWXRW7+Up/i2QsYax0CtZ44byfbVybR8Yo1mMEbgn\naRZm21lcfGeCsTCaxSot8tYBPLe1rYNW6NsOfE1jLPT+HnnpmKi5caGedmP7YVGH6a5lLMaxjg25\noZz6VOOioUx130qexQsfvh8+rI3F/OV8OHwS3yjfjZAHRotafu877Dh9T7As28yJHm3ZVQbbaFDD\nFYdZmLIs7raE1XH6oli4NBxht2BV1Wio6dxQN1+5wKMum9Ns8NxQakw0NnR29J5vBKPGokjK25wb\n6soDxXN7QWoWNaaEH6oH5FwKfFWZhRCKXVSYRac9zlj0+LHn3cDTrmzahKuSZuEmd1WMRZSqSJjP\nzj0NHvvS8WPzzOSrjYXup8DM0QnMYvRBKzMLZ+K0LouKf3tMngXAX/svxvuK/zF+nCjRMdCd5Jqy\nYBYTsR6zMFjLDTVOz7AT5kY1izUE7koGtzVG+nzfFj2GQ2KJmeT0aBj3zGHr4gw8j2XNLJqZdgmZ\nEi3j3FCusWjM2mgo11iUJkBfVzw2hs+cuwc+oe/H4ZrRUF92/SHe9sNftiWTatkN5fytt13VLECx\npFY46kp1f09CtIYQ/0cvewKPvmyefZ1zWFTuEDaVKyGEeImU8q1bPZgLCl44OcdiWrQrxgKUsTBi\nq548Z9rOisxUQU36HD7UBC8uVmxu6Kx5+IWv3FBSWsMWxSob+n1XvJyHP+prxo9Nr747Om/BN4Zo\n9siEaKh13FDu5GObBGVqfOa9CdFQxxceD49+BmshjBoQQ4NpjEVl4nXhliQfayz0NR/nfzdVfzdq\nLGSOquUiCyM/wiyM1pMWobPAoq9dlenSmpF5ngfLssNhcZZGtqrcmcbgDVfGREM5164xZ6OhwtZl\npj16eWI3fc3NsT/smfD5t8Obf6g41jWMxVai5IZyJvoXPvIoeS65fN+oTtcI/FKOBUyvWVhmMaZ1\n6pc/8ihf/sijI6/vRWzWTP/ylo7iQsRlj7f+4E3j6KOUQXDLYJvJSnj29bGahY6IKtF733FDmRXq\nzGG1qjPZyRTGQjYr/RhcmAY4upyEZ5hD55AtSWIxxlj4vlcRuMe4oUx2r3GfTGAWly6sHw1jIsYa\nebkk+ljYEOOKXgDlkOY13VATjAUUPT82olnY6KEqs6h290tK53spcFxza+hnhlnM0SNMVqExXxg8\nwyyEV4y5mk+SDCBe4fE3XGFFaLdB0Ii435iF73ibSiK97U3qtTXcUFuJan0mgwMzDV72pVePLffd\nCLxSXShwo6E2p1mcb9hsFvb2F08/33Hzt6mfc8FNXwOP+OpSPSRrLFr77IMrXF3BvG+TqnrFJOtG\nGhnf9+GbYOVB+OJ74OFfAUCYKGMh2msYC736bosEJLatJ405230NKHzUojwxhtXaUF7FcBgx1AvU\nuL2gcItoNAMfIeDShQm6ivvZRhNWIDKBe9PoBeM0i3XdUIZZTHBDQVGQcC2DVdIscmUw074TDWWY\nRcUNlcXq2urjWw6d5M41mIXVLLweQbysJvHIZRZxhf1V3VBKs4hac3z8vz2f091Kx0TjWjRuKOEr\nF9j8lXDqDvXaDhkL1w01rVtrvh2WKjPD+BLl47CWG+p8wmaNhVz/IzXOGUKMah7GGLirbFe4PHCt\n+n3mi3DNM8rJTiX3ip50bnwRnPwsfPjV1lgE8RKp9AiqJbZd2MqjMUjwAn0rNWbV5GLcWhMif3zX\nDSW8skF0V6HCh4d/pdpu5Vx4nuDHnncDX3b9QdZD1FQGJcw24oYao1lMzSzWMBam495GQme9oHDl\nwJg8i4obSn9/NXLOzZrMQrBMh1l6iOGyKsRomMVwVe236io04wxbqjpynkBjhijwuGS+2n/cuKH0\n4sHcD3OXwp3/ov5eI3R2KzEpz2It/M433TzCDIrCg9O5oc4HEXstnN+jvxhhjYU7CZhicjoc0gvh\nzBfUayU3lBM6a9wYYRue+F1w1zvhpFrhBfEyi8yUiqGNQAiV2OZVNIvGrJqsjKtlgn8+dEuUe5UV\ndskN5akifs/972OH8SPPvZ6br1yDAWm0tLEI8mmYhRs15rihgmaR8wLjjYXJH5ikWUDhItyIwC08\nbPMkcPIszDk0TKTshsJvcFZqw7WmZiFYkS3Vx335AcXirBtqpRydBmWhO2wV4dfj3G/mc244tGss\nTL2oHWMW4zWLtXDF/jaH58oM1kZDBWtvo+lkcJ/POL9HPwZCiJcIIV69tLS020PZHlhj4axwzYQR\nNNRDuP8aOK2NRdIroqHcSdC4ofwQHvet6m+9wpvJVxCtBZ718PGhqBZ+REtHQ/kus4DCFTXBWJSY\nxdh8hKQQuLcADa1ZBNk5aBZhe+1yHuBEQ40zFoZZaDfUVJpF6gj94WRmYbOky8bC9wQPSX3PrGEs\nDLMAVJJmc07fT+Habig/VJ/rap1q3Dkxn3eZmrmuc5cVn9kpY+FWgZ2SWYzDtMzC1IY6391Qmz1T\nY5oW7A3smaqz2wUjdrtuqKor4sB1yljk+QRm4bihvECV9fYbSrsAvMEiBw4eKbWWHAsvtIlZJc0C\n1jUWoa96cI97b0Tg3gK0Wuoc+KmZqKfQC1zNonNInSd3wg3HuaH0+2u6oTagm+SZuo5exVhUM7ih\niCJzoqFC3+OEMRZrROcZzcLCBEo0ZrQbKp1gLCKVYGfa6ZpEvpHjCSrZ6/7o53cqGmoTbqhxMCGz\n4TqMwdaGGhMNdT5hU6OXUj5/qwdSY0oYRuFWpa2GT+5/mOoSl3QBOUazSJ1QyFCtSmePFiGv/bNj\nW4aOwA9toULfrzILLbBXJwfzVbdE+QiziMoC9xag3VaGzzOT2pqr+jGaxfN/Ab79zQVz8KPRJDeY\nklls0A1lmIXrhqpmcEM5NFcfX+ALjm+UWUBh9BuzRTRUNWLN/DauNy+EK548fgdVN5TYI8biHFxD\ntp+Ft7YbarN9N/Yazu/RX4wYJ3Dbej0Os8iGo1EmpczkStz87CVlY9FaXwcgatOWaqUuvAluqKqP\nWiPwHTfUiGYRlgXuLcDNVx4kRyCMsVgzEqkShgpq8pw55DCHCS6TziG4+WVw3XNH3xtxQ21As/A8\nbLkQGM2zgLFuqMDzeAjDLCYL3KPMQhuLaHaCG8pxIRoDecWXTD4vfqTF9yqz2Hk3lO8Jq1VMq1mM\nQ7jR2lAXqRsKACHE5LuvxvZgbDTUGDcUwIO3qN8jSXmx061NT0qzR60bisFiObdjEqIZOlIXnTMP\n/5SaReh5jmaxlhtqa9YzX3rdQTw/Qmxkoh5XTnytaCdQ5+Grfw8OP2L0vY0wC2MkRzQLUxuqklEN\n2OZKWWKvdeCJwg21BrMQQrAqJrmhdFLeJGZhzsk1Ton1Kvyg3PzIHLtuhgXsmLGAgl1siWYxRZ5F\n5Hsjda3ON5zrk/jz5g8hxNPOcVs1psGRR8MzfhJu+PLiNfvg6snAhM8+VDEWVrhNym4oKJhFnqkw\nyKmYxQzt3BiLjQvctq3q2GiorRW47XYN1tQsPBV95JbasMZiDU1i3f2baKiNCNxO69FSNNQEZpHG\n6Fhm9bbrhlqnqGVXOK4z1w01jlm4CxRT5+maNbLoTbkPK3B7xfYb8yp4YIv0qWnQDH1CX4xNwJsW\nVrNYx+D4nuCvvu/JfOuTr9z0vvYCztVYvF0I8XIhxLcCL9qKAdVYB34Az/np8mRuHtzAcSmF7YJZ\nhFVmkToCt35t7hLlm14+pv6fylh0VDVTcJhFVeAeX45b0X9BKqJRl5Arhm7lBOLuZ73tmom5midi\nqqVuZhW8KYG7yixMxeBKBjeo9yuGKPQ97jUNntZhi9//gscV/xhmEXXUNtdyQ136eKVVXPaENY7H\nuMjGuCXnLt1RVgEqnPVcxG1g6n4WAE+8ej8LW1AEcTexaV4khHgNsATcDHxQSvlTWzaqGhtDNRpK\nCNh/LRz/tPrfuqE8NemUQmcdAwNw4nb1exqB233AR5iFEbgnJ+UBpF5EMCnPYgsFbrtdM9b1VpR+\nWA6dHWEW52AsTAb3muzG1Sx0NJSpWguKWXhBJZkxLPJb9GTue4LPyStZ+Za3Mfuwtcn/dz/zRniv\njmyyxmJGRdQ1FyqRV44b6oYXqJ81jz0cL3CDMhZGS9ohNAP/nI1F4Hl4gnJZkwsYm34SpZTfI4Ro\nAY8HniSE+CMp5fdv3dBqTI3AeXANDlwLx29Vf7uJZCb8stL5zJajPvEZ9XtKN5SFO5ma2HwoJttq\nuQ/9oGZeNEGzSLZU4LbbhbUnaQPPL4fOTqtZrLn/qhtqI9FQnqPl5HqlX9EgvHCEtdjKqFc/dTr9\npzkPq/2CIUadwg3lRnhttLlXtZKwe+xf8nJYeWC67WwRlBvq3JlFcI7bOJ8wlbEQQgSontt3SGkU\nTdAd8t6nf2rsFqrMAgrdAiqTugmvrLihLLP4rPo9jcDtJmAZH7QQhZ8b1tQsADKvsXY01BYJ3Ha7\nY8YyFvY8bQOzSHqAWPvYxmkWfgh3vQtedaVayVdDd/1gxFiE3gZLTTTnYfUhJxqqo5hFXhW4y300\n1oVNtKyU+wC48YXTbWML0Qw9onOIhAJ49o2HkRdR4aNpmcUbgEcDCCG+C/jvwCHgHcB/k1IO1vhu\nje2GeWBdN4GJiILyxGZq9LgZ3LBJZjHGDQVTGQsTsqiYxRpuqO1gFlUmMw4jjYqMZrFGv4pp95/0\n1zdY4zQL8514BU59fpRZBE7ZDf39r3j0JbQif3pXSXO+HOEUddR5iLuTo6GmgZswCMXiYpfQDP1z\nyrEAePr1B3n6FHXJLhRMe7YeDdwAfCXwNuDPgO/Q3/+N7RlajakhhHpo3Qd3v8Ms3H4YVritREM1\nZhUDMbkZU2kWY9xQUK48O0HgNglNuakoW3rTEUO3Q+Cexg1lNYsJxmJTzMJxQ61rLKp5Fj6c/WLx\n/sqDo8yiOecYC7Wvmy6d4weffR1Tozmvrp/RdMw17p+dLHBPAxsNpV1q59IUbAuwFW6oiw3TMosV\nKaUE7hBCPCCl/AsAIcSPAx/ettHVmB5+o+KGmsQsKpqFO3HOXgKnP696WXemWDGVmIUzqTfnxjCL\n8Y1jBo2DKpGtdCyREnC3U+BeD5M0C89TpeevHZN0N+3+p2IWrmaRK2Zh2rmCqsV0oGIEGnOqrpP7\n/Y1i/vKiuRYU17i/WDEWG2QWXqiOI4u3li1uEt/1tKs5vRrv9jDOK0x7Rx0VQnw78EnAnmEppRRi\nl/lkDYWgUn6ivV+tEtO4PFGbMtfVPAuAR7wEzt4NL/5f063oJzKL2SLBb4KxMP2MP/KE3+Cymy+v\nHEtTGYp0iyeWDbmhqqGzzne++vfPbf9Jb33mNo5ZfNNfwfHb4J2/DMjRJLvm3GjS20bx/F8oIqrA\nWRDI8W6oaVgaFN9NB1u7ANgknnrtxeM+2ipMe9V+DngS8D3A5UKI24DPALejtIsau42n/ABccnPx\nvxBq5Xn27vLnqslR7oP7vJ/d2D4nMYvGbOHOkuPdUAdnGrz2u57El1yzH6ql0E2toaQ70vDonLAh\ngTsYL3Bvxf6n2Z4rcMsMRKj6etzwQnjXryqjUHUBNZ3imdMYxHFozgHOOXcXBKWkvAl1vSahxKp2\nn1nU2DimuqOklK92/xdCXI7SMR4DvGcbxlVjo3jGT4y+dvQxRXVSA+uGqtSG2gzciURUjMWgmmcx\neqs968bD47drEt+Gq9NpJ9NiI6thP6iU+9iCCa6UQb4BgdvVbjxfnZP+mVGB2zWsW7V6L7kwz8EN\n5TKLPeCGqrFxTBs6K7RmAYCU8n7gfuAfJ32mxh7AC36pCKU0MCtmm2cx5cpwHKaKhhpfSHBNGGYR\nd7dHs5jmmE3o7ARmdE77n2Z746rOGrQPKGMxTuCedvvToqp32b/PwVhsZTh0jR3DtFftnUKIHxZC\nlIqbCCEiIcRzhBB/ioqOqrGX0JhRlVJd2Egjs2LeJmORDZVIvQazmAjDLOLVbYqGmmKbI6GzWzD5\nel6xnfXcROPyLAxMmfo1mcU5XFcXk9xQm4mGAkhqZnG+Yton4IXAdwOvE0JcAywCLZSx+Wfgt6SU\nn9iWEdbYWhjhNktGe19vFG5Gb0mzMPWhVjc32ZrCdHF3aycWIwhvKHR2C5kFYDvGbUizyEeZBYwR\nuBec72/ReSstCMYl5W0gGgr2jMBdY+OYVrMYAH8A/IEQIgQOAn0p5eI2jm1TEEK8BHjJdddtILb8\nYoIpRpcn5776XEvgBlUfqtpGcxoYNxRym5jFlKGz6TYkkfkhJFOMYUSzcPZvmcV56IaqBe7zFtNq\nFuNq64ZCiGqoyqKUcvnch7V5SCnfCrz1iU984vft5jj2LDxdEiJLzk3chsluKOO6iFdVHaPq++vB\nuKFgazN9N6xZ9LbWDeWOYb3tCaGLPo7RLFraWFSZheuGOhctykU4SeDepBuqFrjPW0z7BPwpIIG1\n0i4l8FpUdneNvQq3Qc5mwysNwgnGwmSMJ/3NRRNZZsHWuiw2lJS3DZpFaQzT6ibpGM3iQHlbBtvB\nLPxA5b2kgy1kFrXAfT5iWjfUs7d7IDV2CN4WuqH8QLGAtF9eLRrNIdnkytxlFrvlhrLuuq02FpvI\n9RiJhprALNw8i608b1FHG4txzGKj0VDDNTv21di7qE38xQbLLNKtcVXYXhnjjMVgkwK3wyy2JYN7\nyhLlW52U545hamORFf0sDCYxi7BdnK+tZGS206KzP8Me3Wu1FowgHq/WAvd5itpYXGxwa0NtlbEQ\nfrkw3FhmsYFJf9uYxUZcQG65j3XKiW9qDFOK7BvRLIQoXFFbFToLhbvRvV/mLoH/8Bq46Wum24YZ\n12CpFrjPU9TG4mKD289iKyaUaGb04bfGor+5lXm4XQL3BqrOlvSCrdRNNprrMS4ayjCLMe4cI3Jv\nN7MAePTXl3WStWBdZLIWuM9T1MbiYoPtZ5FsDbNozIxOTFbg7jkZ0BsRuF1msUsCt1vuY1dF9gkZ\n3DCawQ3FpLzVmgWcW/RcKWGwnnbOR9TOw4sNrntlKybBqDPGWDjMAl0BZiP78iNU4N1W51lsotzH\nlvfU2EhrV6NZjMngft7Pw01fPfodYyy2KnQWilDoc4mea8xhr2nNLM5L1MbiYkNJszjHPAvQmkVl\npRg4xsJMMBsxFkIog5P0tljg3mAkkunstpuJgeOYhRDw9B8d/52ddENtBJ6nm2It1QL3eYqaD15s\n8LbYDRWNcUP5gW5gtEnNAoqOdNuyqp9iLEGjqKG1LW6ojWgW+fTnoblHjQU4Y6uZxfmI2sRfbPC3\n2A113fPKbVsNgpZmFnqC2ahQHbagv4nvrYWNuKGChsot2DOaxZTnYVuZxTkuLprzsHRf7YY6T1Eb\ni4sNxhefxWUhebN49NernyqMGymaGQ2tnQaWWWxHJNI0AndDd+sb7rKxGKNZrAUrcG+lsTCaxbky\nCzO22qFxPqK+ahcb3FLRW6FZTELYKsp9bGbiMmxlN91QoLr17dYYJmkWa+HSx8GhR4xne5vFlrmh\ntLGomcV5iZpZXGwwgnPS216hMWyfo7HQzGK3Mritsejvfp6F3IBm8fCvVD9bia1yQ22Hi6zGjqFm\nFhcbTMhm0t/a8MoqjBtqs0lte0HgBoi32KhupphhtZ/FTuOqp6ne33OXndt2tiMHpMaOoTbxFxts\n9c/e1paEqKLkhtrEmsToKdvBLKbVLGDraxlt1FiYXum7OcEefjh8y+vPfTu1G+q8Rs0sLjaYSSru\nbrNmcY5uqL3CLHY118NXAjtsbVTYbsGGzl4Ax3IRor5qFxvMZCWzc+9nsRbCpjIWcpNuKMMstiMh\nbiOaRbxdAveUmkUWq78vCGOxDZFaNXYMF8AdWGNDCNzGQtvphmoXhQTPhVlsixtqmh7c26xZTFVy\nJCiYxYXg56/dUOc1amNxseHwTcXfOyJwb7JcxraEzm4gEqkUOrtLuR6eD5lxQ10AE2wtcJ/XqI3F\nxYbDN21Psbkqtip0disn6saccue0Ftb/rDEWu5rB7UMaF3+f7zChsxeC4bsIURuLiw2eB1c8Rf+9\nA8wiSzY3OZhihFvpq585BC9/Nzziq6bYv9MrYrfYjRdcoMyinnbOR9RX7WLElU9WvwdL27ePsAXI\nzSe1hdsQDQVwyWOmY1RuY6HdDJ21zOICeFSbC+p3LXCfl7gA7sAaG8blT1K/j31s+/ZhmMHqQ9CY\n3fz3d2tFHewBYxG2lWYCFwizqN1Q5zMuOGMhhHiJEOLVS0vbuGo+33H5l8DClfCsV27fPkzo66k7\nYX4Tmb/bxSymxXa5oYINGIvWvu0Zw27BD1U/75pZnJe44K6alPKtwFuf+MQnft9uj2XPImzCj966\nzfvQ0UxpH+Yv3/j3DbPYrYmlFGK8S4mBrrG4UFbjL/ltOPLI3R5FjU3ggjMWNfYI3PLnc5swFuE2\nCNwbgZvdvlvNjy40ZgHwmG/Y7RHU2CQuODdUjT0Ct0T2ZpjFnnJD7VKehRvie6EwixrnLWpjUWN7\n4DKLzWgWuy1wbzuzmCIiq8Qs6ke1xu6ivgNrbA/O1Q1lIme2opvfZiBEET5baxY1atTGosY2wUzy\nQQva+zf+/SOPgm/8M3jYs7Z0WBvCtrZ2vUg1ixrnLWqBu8b2wBiL+cs23n8b1Hdu+uqtHdNGEUQw\nZGuNxcxR5YKaRsepmUWNPYTaWNTYHhiBezPi9l7BdlS+nbsEfuq+6dxrYVu5rbK4ZhY1dh21G6rG\n9sBMhpvRK/YKNqIvbATT6jBCFOyiZhY1dhm1saixPQjbEM3Awet3eySbx3Z069sojLGoo6Fq7DJq\nN1SN7YHnwyveC7OX7PZINo+NlObYLpjiezWzqLHLqI1Fje3D/oft9gjODTZ0dhcfE8ssamNRY3dR\nc9saNSYh2EPGomYWNXYZtbGoUWMSgm1IytsoamZRY4+gNhY1akxCzSxq1LCojUWNGpOwHeU+NgpT\nTLCOhqqxy6jvwBo1JmE7yn1sFNYNVcei1Nhd1MaiRo1J2Auhs9c/H571U3DoEbs3hho1qENna9SY\njL2QlNec3972tzVqTImaWdSoMQnbVe6jRo3zELWxqFFjEvZCNFSNGnsEtbGoUWMSamNRo4ZFbSxq\n1JiEvRA6W6PGHkFtLGrUmATDLOqEuBo1amNRo8ZE1G6oGjUsamNRo8Yk7IWkvBo19ghqY1GjxiTU\nobM1aljUxqJGjUnYC0l5NWrsEdTGokaNSag1ixo1LGpjUaPGJFzxZHjqD8PlT9ztkdSoseuol0w1\nakxC1IYX/NJuj6JGjT2BmlnUqFGjRo11URuLGjVq1KixLmpjUaNGjRo11kVtLGrUqFGjxrqojUWN\nGjVq1FgXtbGoUaNGjRrrojYWNWrUqFFjXdTGokaNGjVqrAshpdztMWwLhBAngXs28JWDwKltGs75\nhPo8KNTnQaE+DwoXy3m4Skp5aNwbF6yx2CiEEB+VUl70dR3q86BQnweF+jwo1OehdkPVqFGjRo0p\nUBuLGjVq1KixLmpjUeDVuz2APYL6PCjU50GhPg8KF/15qDWLGjVq1KixLmpmUaNGjRo11kVtLGrU\nqFGjxrqojQUghHihEOJzQog7hRCv3O3x7BSEEHcLIW4VQnxSCPFR/dp+IcS/CCE+r3/v2+1xbgeE\nEH8ihDghhPi089rYYxcKv6Pvj1uEEI/fvZFvHSacg58TQhzT98QnhRBf4bz3U/ocfE4I8eW7M+qt\nhxDiCiHEO4UQnxFC3CaE+E/69YvqflgPF72xEEL4wO8DLwJuAr5ZCHHT7o5qR/FsKeXjnBjyVwL/\nKqW8HvhX/f+FiNcCL6y8NunYXwRcr39eDvzhDo1xu/FaRs8BwG/qe+JxUsp/ANDPxDcBj9Tf+QP9\n7FwISIH/IqW8CXgK8IP6eC+2+2FNXPTGAvgS4E4p5V1Syhj4a+Crd3lMu4mvBv5U//2nwNfs3lC2\nD1LK9wBnKi9POvavBv5MKnwQWBBCXLIjA91GTDgHk/DVwF9LKYdSyi8Cd6KenfMeUsoHpZQf13+v\nALcDl3GR3Q/roTYW6qa4z/n/fv3axQAJ/LMQ4mNCiJfr145IKR/Ufz8EHNmdoe0KJh37xXaP/JB2\nr/yJ44a8KM6BEOJq4GbgQ9T3Qwm1sbi48XQp5eNRtPoHhRDPcN+UKq76ooytvoiP/Q+Ba4HHAQ8C\n/3NXR7ODEELMAH8D/KiUctl97yK+HyxqYwHHgCuc/y/Xr13wkFIe079PAG9CuRWOG0qtf5/YvRHu\nOCYd+0Vzj0gpj0spMyllDvwxhavpgj4HQogQZSj+Ukr5t/rli/5+cFEbC/gIcL0Q4hohRIQS8d6y\ny2PadgghOkKIWfM38ALg06hj/w79se8A3rw7I9wVTDr2twDfrqNgngIsOe6JCwoV3/vXou4JUOfg\nm4QQDSHENShx98M7Pb7tgBBCAK8BbpdS/i/nrYv+fnAR7PYAdhtSylQI8UPA2wEf+BMp5W27PKyd\nwBHgTeo5IQD+Skr5T0KIjwBvEEJ8D6rE+zfu4hi3DUKI1wHPAg4KIe4HfhZ4FeOP/R+Ar0CJuj3g\nu3Z8wNuACefgWUKIx6FcLncD3w8gpbxNCPEG4DOo6KEflFJmuzDs7cDTgJcBtwohPqlf+69cZPfD\neqjLfdSoUaNGjXVRu6Fq1KhRo8a6qI1FjRo1atRYF7WxqFGjRo0a66I2FjVq1KhRY13UxqJGjRo1\naqyL2ljUqDEGQoj3699XCyG+ZYu3/V/H7atGjb2MOnS2Ro01IIR4FvDjUsoXb+A7gZQyXeP9VSnl\nzBYMr0aNHUPNLGrUGAMhxKr+81XAl+neDj8mhPCFEL8uhPiILrb3/frzzxJCvFcI8RZU4hpCiL/T\nRRpvM4UahRCvAlp6e3/p7ktnBP+6EOLTQvUZeamz7XcJId4ohPisEOIvddYxQohX6T4MtwghfmMn\nz1GNiwsXfQZ3jRrr4JU4zEJP+ktSyicJIRrA+4QQ/6w/+3jgUbqEN8B3SynPCCFawEeEEH8jpXyl\nEOKHpJSPG7Ovr0MV8HsscFB/5z36vZtRvSQeAN4HPE0IcTuqJMfDpZRSCLGwtYdeo0aBmlnUqLEx\nvABVF+iTqDLWB1B1kgA+7BgKgB8RQnwK+CCq8Nz1rI2nA6/ThfyOA+8GnuRs+35d4O+TwNXAEjAA\nXiOE+DpU6YkaNbYFtbGoUWNjEMAPO53krpFSGmbRtR9SWsfzgC+VUj4W+ATQPIf9Dp2/M8DoIl8C\nvBF4MfBP57D9GjXWRG0satRYGyvArPP/24Ef0CWtEULcoKv2VjEPnJVS9oQQD0e16zRIzPcreC/w\nUq2LHAKewRqVXXX/hXnd+vTHUO6rGjW2BbVmUaPG2rgFyLQ76bXAb6NcQB/XIvNJxree/SfgFVpX\n+BzKFWXwauAWIcTHpZTf6rz+JuBLgU+hqr7+pJTyIW1sxmEWeLMQooliPP95U0dYo8YUqENna9So\nUaPGuqjdUDVq1KhRY13UxqJGjRo1aqyL2ljUqFGjRo11URuLGjVq1KixLmpjUaNGjRo11kVtLGrU\nqFGjxrqojUWNGjVq1FgX/z/8NBz3WsKQ9wAAAABJRU5ErkJggg==\n",
      "text/plain": [
       "<Figure size 432x288 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAYUAAAEWCAYAAACJ0YulAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\nRSEiIpoUhYiIaFIUIiKiSVGIiIjmN0XdwbQkk+yAAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<Figure size 432x288 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "kappa = 30\n",
    "s = np.logspace(0, np.log10(kappa), d)\n",
    "A = (u, s, vt)\n",
    "\n",
    "newtons, cosines = [], []\n",
    "memories = [5, 50]\n",
    "\n",
    "for color, memory in zip(['r', 'g'], memories):\n",
    "    lbs, newton, cosine = lbfgs(A, memory, extras=True)\n",
    "    matrix_name = r'logspace eigenvals, $\\kappa = {kappa}$'.format(kappa=kappa)\n",
    "    plt.semilogy(lbs, c=color,\n",
    "                 label=r'L-BFGS ($m = {memory}$)'.format(memory=memory))\n",
    "    newtons.append(newton)\n",
    "    cosines.append(cosine)\n",
    "\n",
    "gds = gd(A, max_iter=len(lbs))\n",
    "plt.semilogy(gds, c='b', label='GD')\n",
    "    \n",
    "plt.legend(bbox_to_anchor=(1.05, 0.5), loc='center left')\n",
    "plt.xlabel('iterations')\n",
    "plt.ylabel('function optimality gap')\n",
    "plt.title(matrix_name)\n",
    "plt.show()\n",
    "\n",
    "\n",
    "for newton, memory in zip(newtons, memories):\n",
    "    newton = np.array(newton)\n",
    "    index = np.arange(len(newton))\n",
    "    q = np.percentile(newton, 95)\n",
    "    plt.semilogy(index[newton < q], newton[newton < q],\n",
    "                 label=r'$m = {memory}$'.format(memory=memory))\n",
    "plt.xlabel('iterations')\n",
    "plt.ylabel(r'$\\|(B_k -\\nabla_k^2)\\mathbf{p}_k\\|_2/\\|\\mathbf{p}_k\\|_2$')\n",
    "plt.title('Directional Newton Approximation')\n",
    "plt.show()\n",
    "\n",
    "for cosine, memory in zip(cosines, memories):\n",
    "    cosine = np.array(cosine)\n",
    "    plt.plot(cosine,\n",
    "                 label=r'$m = {memory}$'.format(memory=memory))\n",
    "plt.xlabel('iterations')\n",
    "plt.ylabel(r'$\\cos \\theta_k$')\n",
    "plt.title('L-BFGS and GD Cosine')\n",
    "plt.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "So, as we can see above, it's not quite right to look to either $\\cos\\theta_k$ nor $\\|(B_k-\\nabla^2_k)\\mathbf{p}_k\\|/\\|\\mathbf{p}_k\\|$ to demonstrate L-BFGS convergence (the latter should tend to zero per BFGS theory as memory tends to infinity). But at least for quadratic functions, perhaps it's possible to work out the linear rate acceleration observed earlier via some matrix algebra.\n",
    "\n",
    "A follow-up question by Brian Borchers was what happens in the ill-conditioned regime. Unfortunately, the Wolfe search no longer converges, for GD and L-BFGS. Switching to backtracking-only stabilizes the descent. We end up with noisier curves so I geometrically average over a few samples. Note the rates are all still linear but much worse."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "2020-11-01 19:04:02,703\tERROR worker.py:655 -- Calling ray.init() again after it has already been called.\n"
     ]
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAgoAAAEaCAYAAABw/39TAAAAOXRFWHRTb2Z0d2FyZQBNYXRwbG90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\n",
      "text/plain": [
       "<Figure size 432x288 with 1 Axes>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "kappa_log10 = 5\n",
    "s = np.logspace(0, kappa_log10, d)\n",
    "memory = 5\n",
    "\n",
    "import ray\n",
    "ray.init(ignore_reinit_error=True)\n",
    "\n",
    "# https://vladfeinberg.com/2019/10/20/prngs.html\n",
    "from numpy.random import SeedSequence, default_rng\n",
    "\n",
    "ss = SeedSequence(12345)\n",
    "trials = 16\n",
    "child_seeds = ss.spawn(trials)\n",
    "maxit = 1000 * 100\n",
    "\n",
    "@ray.remote(num_cpus=1)\n",
    "def descent(A, algo):\n",
    "    if algo == 'lbfgs':\n",
    "        return lbfgs(A, memory, armijo=True, max_iter=maxit)\n",
    "    else:\n",
    "        return gd(A, max_iter=maxit, armijo=True)\n",
    "\n",
    "@ray.remote\n",
    "def trial(seed):\n",
    "    rng = default_rng(seed)\n",
    "    \n",
    "    vt = haar(d, d, rng)\n",
    "    u = haar(n, d, rng)\n",
    "\n",
    "    A = (u, s, vt)\n",
    "    \n",
    "    lbs = descent.remote(A, 'lbfgs')\n",
    "    gds = descent.remote(A, 'gd')\n",
    "    lbs = ray.get(lbs)\n",
    "    gds = ray.get(gds)\n",
    "    lbsnp = np.full(maxit, min(lbs))\n",
    "    gdsnp = np.full(maxit, min(gds))\n",
    "    lbsnp[:len(lbs)] = lbs\n",
    "    gdsnp[:len(gds)] = gds\n",
    "    \n",
    "    return lbsnp, gdsnp\n",
    "\n",
    "lbs_gm = np.zeros(maxit)\n",
    "gds_gm = np.zeros(maxit)\n",
    "for i, fut in enumerate([trial.remote(seed) for seed in child_seeds]):\n",
    "    lbs, gds = ray.get(fut)\n",
    "    lbs_gm += np.log(lbs)\n",
    "    gds_gm += np.log(gds)\n",
    "lbs_gm /= trials\n",
    "gds_gm /= trials\n",
    "\n",
    "matrix_name = r'logspace eigenvals, $\\kappa = 10^{{{kappa_log10}}}$, GM over {trials} trials'.format(kappa_log10=kappa_log10, trials=trials)\n",
    "plt.semilogy(np.exp(gds_gm), c='b', label='GD')\n",
    "plt.semilogy(np.exp(lbs_gm), c=color,\n",
    "             label=r'L-BFGS ($m = {memory}$)'.format(memory=memory))\n",
    "plt.legend(bbox_to_anchor=(1.05, 0.5), loc='center left')\n",
    "plt.xlabel('iterations')\n",
    "plt.ylabel('function optimality gap')\n",
    "plt.title(matrix_name)\n",
    "plt.show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.6.1"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
